@@ -131,6 +131,7 @@ public final class ConfigKeys {
 		public static final String ICFG_MERGE_SAME_SIZE_FILES_TOLERANCE = "Merge Same Size Files Tolerance";
 		public static final String ICFG_MERGE_SAME_SIZE_FILES_MIN_PIECES = "Merge Same Size Files Min Pieces";
 		public static final String BCFG_CHECK_PIECES_ON_COMPLETION = "Check Pieces on Completion";
+		public static final String BCFG_CHECK_PIECES_ON_COMPLETION_BEFORE_MOVE = "Check Pieces on Completion Before Move";
 		public static final String BCFG_SEEDING_PIECE_CHECK_RECHECK_ENABLE = "Seeding Piece Check Recheck Enable";
 		public static final String BCFG_FILE_STRICT_LOCKING = "File.strict.locking";
 		public static final String ICFG_MAX_FILE_LINKS_SUPPORTED = "Max File Links Supported";
@@ -138,6 +139,7 @@ public final class ConfigKeys {
 		public static final String ICFG_INSUFFICIENT_SPACE_DOWNLOAD_RESTART_MINS = "Insufficient Space Download Restart Period";
 		public static final String BCFG_MISSING_FILE_DOWNLOAD_RESTART = "Missing File Download Restart Enable";
 		public static final String BCFG_SKIP_COMP_DL_FILE_CHECKS = "Skip Complete Download File Checks";
+		public static final String BCFG_SKIP_INCOMP_DL_FILE_CHECKS = "Skip Incomplete Download File Checks";
 		public static final String ICFG_MISSING_FILE_DOWNLOAD_RESTART_MINS = "Missing File Download Restart Period";
 		public static final String ICFG_SAVE_RESUME_INTERVAL = "Save Resume Interval";
 		public static final String BCFG_ON_RESUME_RECHECK_ALL = "On Resume Recheck All";
@@ -184,6 +186,7 @@ public final class ConfigKeys {
 		public static final String SCFG_FILE_MOVE_DOWNLOAD_REMOVED_MOVE_TORRENT_PATH = "File.move.download.removed.move_torrent_path";
 		public static final String BCFG_FILE_MOVE_DOWNLOAD_REMOVED_ONLY_IN_DEFAULT = "File.move.download.removed.only_in_default";
 		public static final String BCFG_FILE_MOVE_DOWNLOAD_REMOVED_MOVE_PARTIAL = "File.move.download.removed.move_partial";
+		public static final String BCFG_FILE_MOVE_ADD_SUB_FOLDER = "File.move.add.sub.dir";
 		public static final String BCFG_FILE_USE_TEMP_AND_MOVE_ENABLE = "file.use.temp.path.and.move.enable";
 		public static final String BCFG_FILE_MOVE_ORIGIN_DELETE_FAIL_IS_WARNING = "Fail To Delete Origin File After Move Is Warning";
 		public static final String SCFG_FILE_USE_TEMP_AND_MOVE_PATH = "file.use.temp.path.and.move.path";
@@ -196,6 +199,7 @@ public final class ConfigKeys {
 		public static final String ICFG_DISKMANAGER_HASHCHECKING_STRATEGY = "diskmanager.hashchecking.strategy";
 		public static final String BCFG_DISKMANAGER_HASHCHECKING_SMALLESTFIRST = "diskmanager.hashchecking.smallestfirst";
 		public static final String BCFG_DISKMANAGER_ONE_OP_PER_FS = "diskmanager.one.op.per.fs";
+		public static final String BCFG_DISKMANAGER_ONE_OP_PER_FS_CONC_READ = "diskmanager.one.op.per.fs.conc.read";
 		public static final String BCFG_DISKMANAGER_HASHCHECKING_MAX_ACTIVE = "diskmanager.hashchecking.maxactive";
 		public static final String BCFG_DISKMANAGER_PERF_CACHE_ENABLE = "diskmanager.perf.cache.enable";
 		public static final String ICFG_DISKMANAGER_PERF_CACHE_SIZE = "diskmanager.perf.cache.size";
@@ -254,6 +258,7 @@ public final class ConfigKeys {
 		public static final String SCFG_LOGGING_DIR = "Logging Dir";
 		public static final String ICFG_LOGGING_MAX_SIZE = "Logging Max Size";
 		public static final String SCFG_LOGGING_TIMESTAMP = "Logging Timestamp";
+		public static final String BCFG_LOGGER_DEBUG_FILES_DISABLE = "Logger.DebugFiles.Disable";
 		public static final String BCFG_LOGGER_DEBUG_FILES_FORCE = "Logger.DebugFiles.Enabled.Force";
 		public static final String ICFG_LOGGER_DEBUG_FILES_SIZE_KB = "Logger.DebugFiles.SizeKB";
 	}
@@ -292,6 +297,7 @@ public final class ConfigKeys {
 		public static final String BCFG_PROMPT_TO_ABORT_SHUTDOWN = "Prompt To Abort Shutdown";
 		public static final String ICFG_STOP_FORCE_TERMINATE_AFTER = "Force Terminate After Mins";
 		public static final String ICFG_AUTO_RESTART_WHEN_IDLE = "Auto Restart When Idle";
+		public static final String BCFG_AUTO_RESTART_WHEN_IDLE_PROMPT = "Auto Restart When Idle Prompt";
 		public static final String SCFG_ON_DOWNLOADING_COMPLETE_DO = "On Downloading Complete Do";
 		public static final String SCFG_ON_DOWNLOADING_COMPLETE_SCRIPT = "On Downloading Complete Script";
 		public static final String SCFG_ON_SEEDING_COMPLETE_DO = "On Seeding Complete Do";
@@ -446,5 +452,6 @@ public final class ConfigKeys {
 	public static class Tag {
 		public static final String BCFG_TRACKER_AUTO_TAG_INTERESTING_TRACKERS = "Auto Tag Interesting Trackers";
 		public static final String ICFG_TAG_AUTO_FULL_REAPPLY_PERIOD_SECS = "Tag Auto Full Reapply Period Secs";
+		public static final String BCFG_TAG_SHOW_SWARM_TAGS_IN_OVERVIEW = "Show Swarm Tags In Overview";
 	}
 }
