@@ -855,7 +855,7 @@ DHTNATPuncherImpl
 
   							dht.remove(
 								getPublishKey( current_local ),
-								"DHTNatPuncher: removal of publish",
+								"DHTNatPuncher: removal of publish", (short)0,
 								new DHTOperationListener()
 								{
 									@Override
@@ -1178,7 +1178,7 @@ DHTNATPuncherImpl
 
 		}catch( Throwable e ){
 
-			log(e);
+			Debug.out( "Originator: " + originator.getAddress() + ": " + Debug.getNestedExceptionMessageAndStack( e ));
 
 			return( null );
 		}
