@@ -135,7 +135,8 @@ DMCheckerImpl
 
 	volatile boolean	complete_recheck_in_progress;
 	volatile int		complete_recheck_progress;
-
+	volatile boolean	check_cancelled;
+	
 	private boolean				checking_enabled		= true;
 
 	protected final AEMonitor	this_mon	= new AEMonitor( "DMChecker" );
@@ -271,6 +272,13 @@ DMCheckerImpl
 	   }
 	}
 
+	@Override
+	public boolean
+	getRecheckCancelled()
+	{
+		return( check_cancelled );
+	}
+	
 	@Override
 	public void
 	setCheckingEnabled(
@@ -304,14 +312,17 @@ DMCheckerImpl
 		complete_recheck_progress		= 0;
 		complete_recheck_in_progress	= true;
 
+			// register the instance here rather than in the thread so that the operation is guaranteed to 
+			// exist when we return so the caller can rely on it
+		
+		DiskManagerRecheckInstance	recheck_inst = disk_manager.getRecheckScheduler().register( disk_manager, true );
+
 	 	new AEThread2("DMChecker::completeRecheck", true )
 			{
 		  		@Override
 				public void
 				run()
 		  		{
-		  			DiskManagerRecheckInstance	recheck_inst = disk_manager.getRecheckScheduler().register( disk_manager, true );
-
 		  			try{
 		  				final AESemaphore	sem = new AESemaphore( "DMChecker::completeRecheck" );
 
@@ -437,15 +448,17 @@ DMCheckerImpl
 		  				}
 		  	       }finally{
 
-		  	       		complete_recheck_in_progress	= false;
+		  	       		check_cancelled = recheck_inst.isCancelled();
 
+		  	       		complete_recheck_in_progress	= false;
+		  	       		
 		  	       		recheck_inst.unregister();
 		  	       		
 		  	       		if ( !stopped ){
 		  	       			
 		  	       			disk_manager.getDownload().fireGlobalManagerEvent(
 		  	       				GlobalManagerEvent.ET_RECHECK_COMPLETE,
-		  	       				request.isExplicit());
+		  	       				new Object[]{ request.isExplicit(), check_cancelled });
 		  	       		}
 		  	       }
 		        }
