@@ -581,7 +581,7 @@ LWSDiskManager
 
 	@Override
 	public DownloadEndedProgress
-	downloadEnded()
+	downloadEnded( boolean start_of_day )
 	{
 		return( new DownloadEndedProgress(){
 			@Override
