@@ -604,6 +604,8 @@ WebEngine
 
 		String lc_url = searchURL.toLowerCase( Locale.US );
 
+		boolean can_proxy = lc_url.startsWith( "http" ) || lc_url.startsWith( "ftp" );
+		
 		boolean explicit_tor = lc_url.startsWith( "tor:" );
 
 		boolean user_tor = false;
@@ -617,14 +619,27 @@ WebEngine
 				user_tor = true;
 			}
 		}
+		boolean explicit_i2p = lc_url.startsWith( "i2p:" );
 
-		if ( explicit_tor || user_tor ){
+		boolean user_i2p = false;
+
+		if ( !explicit_i2p ){
+
+			String test = Result.adjustLink( searchURL );
+
+			if ( test.startsWith( "i2p:" )){
+
+				user_i2p = true;
+			}
+		}
+
+		if ( can_proxy && ( explicit_tor || user_tor || explicit_i2p || user_i2p )){
 
 				// strip out any stuff we probably don't want to send
 
 			searchContext = new HashMap<>();
 
-			String target_resource = explicit_tor?searchURL.substring( 4 ):searchURL;
+			String target_resource = (explicit_tor||explicit_i2p)?searchURL.substring( 4 ):searchURL;
 
 			URL location;
 
@@ -639,8 +654,14 @@ WebEngine
 
 			Map<String,Object>	options = new HashMap<>();
 
-			options.put( AEProxyFactory.PO_PEER_NETWORKS, new String[]{ AENetworkClassifier.AT_TOR });
+			options.put( AEProxyFactory.PO_PEER_NETWORKS, new String[]{ (explicit_tor || user_tor)?AENetworkClassifier.AT_TOR:AENetworkClassifier.AT_I2P });
 
+			if ( explicit_i2p || user_i2p ){
+				
+				options.put( AEProxyFactory.PO_PREFERRED_PROXY_TYPE, "HTTP" );
+				options.put( AEProxyFactory.PO_FORCE_PROXY, true );
+			}
+			
 			PluginProxy plugin_proxy =
 				AEProxyFactory.getPluginProxy(
 					"Web engine download of '" + target_resource + "'",
@@ -663,23 +684,6 @@ WebEngine
 
 				pageDetails	details = getWebPageContentSupport( proxy, proxy_host, url.toExternalForm(), searchParameters, searchContext, headers, only_if_modified );
 
-				/*
-				 * Don't need this anymore, modification is done at link use time if needed
-				String content = details.getContent();
-
-				content = content.replaceAll( "(?i)http://", "tor:http://" );
-				content = content.replaceAll( "(?i)https://", "tor:https://" );
-				content = content.replaceAll( "(?i)ftp://", "tor:ftp://" );
-
-					// handle JSON encoded stuff
-
-				content = content.replaceAll( "(?i)http:\\\\/\\\\/", "tor:http:\\/\\/" );
-				content = content.replaceAll( "(?i)https:\\\\/\\\\/", "tor:https:\\/\\/" );
-				content = content.replaceAll( "(?i)ftp:\\\\/\\\\/", "tor:ftp:\\/\\/" );
-
-				details.setContent( content );
-				*/
-
 				if ( verifier != null ){
 
 					verifier.verify( details );
@@ -724,7 +728,11 @@ WebEngine
 			try{
 				URL 			original_url	= new URL( searchURL );
 
-				PluginProxy 	plugin_proxy	= AEProxyFactory.getPluginProxy( "getting search results ", original_url );
+				Map<String,Object>	options = new HashMap<>();
+				
+				options.put( AEProxyFactory.PO_PREFERRED_PROXY_TYPE, "HTTP" );
+				
+				PluginProxy 	plugin_proxy	= AEProxyFactory.getPluginProxy( "getting search results ", original_url, options );
 
 				if ( plugin_proxy == null ){
 
