@@ -253,7 +253,7 @@ public class BTPeerIDByteDecoderDefinitions {
 		addAzStyle("bk", "BitKitten (libtorrent)");
 		addAzStyle("BR", "BitRocket", "1.2(34)");
 		addAzStyle("BS", "BTSlave");
-		addAzStyle("BW", "BitWombat");
+		// addAzStyle("BW", "BitWombat");	dead apparently and re-used by BitTorrent Web
 		addAzStyle("BX", "BittorrentX");
 		addAzStyle("CB", "Shareaza Plus");
 		addAzStyle("CD", "Enhanced CTorrent", VER_AZ_TWO_MAJ_TWO_MIN);
@@ -376,6 +376,7 @@ public class BTPeerIDByteDecoderDefinitions {
 		addSimpleClient("XanTorrent", "DansClient");
 		addSimpleClient("MediaGet",     "-MG1");
 		addSimpleClient("MediaGet2 2.1", "-MG21");
+		addSimpleClient("FDM", "FD");			// whatever, can't be bothered
 
 		/**
 		 * This is interesting - it uses Mainline style, except uses two characters instead of one.
@@ -476,6 +477,9 @@ public class BTPeerIDByteDecoderDefinitions {
 
 		addAzStyle( "PI", "PicoTorrent", VER_AZ_ONE_MAJ_TWO_MIN_ONE_TRAIL);
 
+		client = addSimpleClient("UW", "-UW");
+		addVersionedClient(client, VER_BYTE_BLOCK_DOTTED_NUM, 4);
+
 	}
 
 	static class ClientData {
