@@ -555,6 +555,61 @@ AEPluginProxyHandler
 
 		return( null );
 	}
+	
+	private static InetSocketAddress
+	getLocalAddress(
+		PluginProxyImpl	pp )
+	{
+		String					host		= pp.getHost();
+		int						port		= pp.getPort();
+		
+		return( getLocalAddress( host, port ));
+	}
+	
+	public static final int LA_EXPLICIT_NET_NONE	= 0;
+	public static final int LA_EXPLICIT_NET_MIX		= 1;
+	public static final int LA_EXPLICIT_NET_PURE	= 2;
+	
+	public static InetSocketAddress
+	getLocalAddress(
+		String		host,
+		int			port )
+	{
+		return( getLocalAddress( host, port, LA_EXPLICIT_NET_NONE ));
+	}
+	
+	public static InetSocketAddress
+	getLocalAddress(
+		String		host,
+		int			port,
+		int			network )
+	{
+		Map<String,Object>		options		= new HashMap<>();
+
+		options.put( "net", network );
+		
+		Object[] args = new Object[]{ host, port, options };
+		
+		for ( PluginInterface pi: plugins ){
+
+			try{
+				IPCInterface ipc = pi.getIPC();
+
+				if ( ipc.canInvoke( "getLocalProxyEndpoint", args )){
+
+					Map<String,Object> reply = (Map<String,Object>)ipc.invoke( "getLocalProxyEndpoint", args );
+
+					String	l_host	= (String)reply.get( "host" );
+					int		l_port	= (Integer)reply.get( "port" );
+					
+					return( InetSocketAddress.createUnresolved( l_host, l_port ));
+				}
+			}catch( Throwable e ){
+			}
+		}
+		
+		return( null );
+	}
 
 	private static void
 	checkPluginInstallation(
@@ -842,6 +897,13 @@ AEPluginProxyHandler
 			return( target );
 		}
 
+		@Override
+		public InetSocketAddress 
+		getLocalAddress()
+		{
+			return( AEPluginProxyHandler.getLocalAddress( this ));
+		}
+		
 		@Override
 		public PluginProxy
 		getChildProxy(
