@@ -30,6 +30,7 @@ import java.util.Map;
 import com.biglybt.core.config.COConfigurationManager;
 import com.biglybt.core.metasearch.Result;
 import com.biglybt.core.subs.SubscriptionResult;
+import com.biglybt.core.subs.util.SearchSubsResultBase;
 import com.biglybt.core.util.*;
 import com.biglybt.pif.utils.search.SearchResult;
 import com.biglybt.util.JSONUtils;
@@ -38,19 +39,19 @@ public class
 SubscriptionResultImpl
 	implements SubscriptionResult
 {
-	private static final long TIME_FOUND_DEFAULT;
+	private static final int TIME_FOUND_DEFAULT_SECS;
 
 	static{
-		long tfd = COConfigurationManager.getLongParameter( "subscription.result.time.found.default", 0 );
+		int tfd = COConfigurationManager.getIntParameter( "subscription.result.time.found.default", 0 );
 
 		if ( tfd == 0 ){
 
-			tfd = SystemTime.getCurrentTime()/1000;
+			tfd = (int)( SystemTime.getCurrentTime()/1000 );
 
 			COConfigurationManager.setParameter( "subscription.result.time.found.default", tfd );
 		}
 
-		TIME_FOUND_DEFAULT = tfd*1000;
+		TIME_FOUND_DEFAULT_SECS = tfd;
 	}
 
 	final private SubscriptionHistoryImpl	history;
@@ -61,6 +62,8 @@ SubscriptionResultImpl
 	private boolean		deleted;
 	private int			deleted_last_seen_day;
 	
+	private int			time_found_secs;
+	
 	private String		result_json;
 
 	private WeakReference<Map<Integer,Object>>	props_ref = null;
@@ -109,8 +112,77 @@ SubscriptionResultImpl
 				Debug.printStackTrace(e);
 			}
 		}
+		
+		try{
+			String tf = (String)map.get( "tf" );
+			
+			if ( tf != null ){
+				
+				time_found_secs = Integer.parseInt( tf );	// already in secs
+				
+			}else{
+				
+				time_found_secs = TIME_FOUND_DEFAULT_SECS;
+			}
+		}catch( Throwable e ){
+			
+			time_found_secs = TIME_FOUND_DEFAULT_SECS;
+		}
 	}
 
+	protected
+	SubscriptionResultImpl(
+		SubscriptionHistoryImpl		_history,
+		SearchSubsResultBase		_base )
+	{
+		history = _history;
+		
+		byte[] 	hash 	= _base.getHash();
+		String	name	= _base.getName();
+		long	size	= _base.getSize();
+		
+		String	key1_str;
+		
+		if ( hash != null ){
+			
+			key1_str = Base32.encode(hash);
+			
+		}else{
+			
+			key1_str = name + ":" + size;
+		}
+
+		try{
+			byte[] sha1 = new SHA1Simple().calculateHash( key1_str.getBytes( "UTF-8" ));
+
+			key1 = new byte[10];
+
+			System.arraycopy( sha1, 0, key1, 0, 10 );
+
+		}catch( Throwable e ){
+
+			Debug.printStackTrace(e);
+		}
+		
+		Map map = new HashMap<>();
+		
+		map.put( "lb", String.valueOf( size ));
+		map.put( "n", name );
+		
+		if ( hash != null ){
+			
+			map.put( "h", Base32.encode(hash));
+		}
+		
+		time_found_secs = (int)( SystemTime.getCurrentTime()/1000 );
+		
+		map.put( "tf", String.valueOf( time_found_secs ));
+		
+		result_json = JSONUtils.encodeToJSON( map );
+		
+		read = true;
+	}
+	
 	protected
 	SubscriptionResultImpl(
 		SubscriptionHistoryImpl		_history,
@@ -147,18 +219,49 @@ SubscriptionResultImpl
 
 				Debug.printStackTrace(e);
 			}
+			
+			try{
+				Number tfs = (Number)map.get( "tz" );
+			
+				if ( tfs != null ){
+					
+					time_found_secs = tfs.intValue();
+				}
+			}catch( Throwable e ){
+			}
 		}
 	}
 
 	protected boolean
 	updateFrom(
-		SubscriptionResultImpl	other )
+		SubscriptionResultImpl	other,
+		boolean					allow_reincarnation )
 	{
 		if ( deleted ){
 
-			deleted_last_seen_day = (int)( SystemTime.getCurrentTime() / (1000*60*60*24 ));
+			if ( allow_reincarnation ){
+				
+				deleted 				= false;
+				deleted_last_seen_day	= 0;
+				
+				key2		= other.getKey2();
+				result_json = other.getJSON();
+
+				time_found_secs = other.time_found_secs;
+				
+				synchronized( this ){
+
+					props_ref = null;
+				}
+
+				return( true );
+				
+			}else{
 			
-			return( false );
+				deleted_last_seen_day = (int)( SystemTime.getCurrentTime() / (1000*60*60*24 ));
+			
+				return( false );
+			}
 		}
 
 		String	my_json_str 	= getJSON();
@@ -379,7 +482,7 @@ SubscriptionResultImpl
 	protected Map
 	toBEncodedMap()
 	{
-		Map		map	= new HashMap();
+		Map<String,Object>		map	= new HashMap<>();
 
 		map.put( "key", key1 );
 
@@ -409,6 +512,18 @@ SubscriptionResultImpl
 
 				Debug.printStackTrace(e);
 			}
+			
+				// one off to back-populate old results with time-found
+			
+			if ( time_found_secs == 0 ){
+				
+				getTimeFound();
+			}
+			
+			if ( time_found_secs > 0 ){
+				
+				map.put( "tz", new Long( time_found_secs ));
+			}
 		}
 
 		return( map );
@@ -485,6 +600,7 @@ SubscriptionResultImpl
 		return (Result.adjustLink((String)toJSONMap().get( "pl" )));
 	}
 
+	@Override
 	public String
 	getAssetHash()
 	{
@@ -495,14 +611,21 @@ SubscriptionResultImpl
 	public long
 	getTimeFound()
 	{
-		String tf_secs_str = (String)toJSONMap().get( "tf" );
+		if ( time_found_secs == 0 ){
 
-		if ( tf_secs_str == null ){
+			String tfs = (String)toJSONMap().get( "tf" );
 
-			return( TIME_FOUND_DEFAULT );
+			if ( tfs == null ){
+
+				time_found_secs = TIME_FOUND_DEFAULT_SECS;
+				
+			}else{
+				
+				time_found_secs = Integer.parseInt( tfs );
+			}
 		}
-
-		return( Long.parseLong( tf_secs_str )*1000 );
+		
+		return( time_found_secs*1000L );
 	}
 
 	@Override
