@@ -32,4 +32,21 @@ TagDownload
 
 	public Set<DownloadManager>
 	getTaggedDownloads();
+	
+	public void
+	applySort();
+	
+	public int
+	getAutoApplySortInterval();
+	
+	public void
+	setAutoApplySortInterval(
+		int		secs );
+	
+	public int
+	getWeight();
+	
+	public void
+	setWeight(
+		int		weight );
 }
