@@ -84,6 +84,7 @@ TagBase
 	protected static final String	AT_RATELIMIT_BOOST						= "rl.bst";
 	protected static final String	AT_RATELIMIT_MAX_ACTIVE_DL				= "rl.maxadl";
 	protected static final String	AT_RATELIMIT_MAX_ACTIVE_CD				= "rl.maxacd";
+	protected static final String	AT_RATELIMIT_ACTIVE_LIMITS_STRICT		= "rl.als";
 	
 	protected static final String	AT_PROPERTY_PREFIX				= "pp.";
 	//protected static final String	AT_EOA_PREFIX					= "eoa.";	// meh, should be used but copy/paste error resulted in AT_PROPERTY_PREFIX being used instead 
@@ -100,6 +101,9 @@ TagBase
 	protected static final String	AT_LIMIT_ORDERING				= "max.t.o";
 	protected static final String	AT_EOS_ASSIGN_TAGS				= "eos.at";
 	protected static final String	AT_EOS_REMOVE_TAGS				= "eos.rt";
+	
+	protected static final String	AT_AUTO_APPLY_SORT_INTERVAL		= "dl.auto.sort";
+	protected static final String	AT_WEIGHT						= "dl.weight";
 
 	private static final String[] EMPTY_STRING_LIST = {};
 
@@ -904,6 +908,32 @@ TagBase
 		}
 	}
 	
+	public boolean
+	getStrictActivityLimits()
+	{
+		if ( tag_rl != null ){
+			
+			return( readBooleanAttribute( AT_RATELIMIT_ACTIVE_LIMITS_STRICT, true ));
+		}
+		
+		return( false );		
+	}
+	
+	public void
+	setStrictActivityLimits(
+		boolean		b )
+	{
+		if ( tag_rl != null ){
+			
+			if ( getStrictActivityLimits() != b ){
+			
+				writeBooleanAttribute( AT_RATELIMIT_ACTIVE_LIMITS_STRICT, b );
+		
+				tag_type.fireMetadataChanged( this );
+			}
+		}		
+	}
+	
 		// initial save location
 
 	public boolean
@@ -1890,6 +1920,38 @@ TagBase
 			});
 	}
 	
+	public int
+	getAutoApplySortInterval()
+	{
+		return( readLongAttribute( AT_AUTO_APPLY_SORT_INTERVAL, 0L ).intValue());
+	}
+	
+	public void
+	setAutoApplySortInterval(
+		int		secs )
+	{
+		writeLongAttribute( AT_AUTO_APPLY_SORT_INTERVAL, secs );
+	}
+	
+	public void 
+	applySort()
+	{
+	}
+	
+	public int
+	getWeight()
+	{
+		return( readLongAttribute( AT_WEIGHT, 0L ).intValue());
+
+	}
+	
+	public void
+	setWeight(
+		int		weight )
+	{
+		writeLongAttribute( AT_WEIGHT, weight );
+	}
+	
 		// notifications
 
 	public int
@@ -2937,7 +2999,7 @@ TagBase
 
 
  	@Override
-  public void
+ 	public void
  	tick(
  		long	mono_now,
  		int 	count )
@@ -3331,7 +3393,7 @@ TagBase
 		}
 		
 		@Override
-		public String 
+		public String[]
 		explainTaggable(
 			Taggable taggable)
 		{
