@@ -31,6 +31,7 @@ import com.biglybt.core.download.DownloadManager;
 import com.biglybt.core.download.DownloadManagerPeerListener;
 import com.biglybt.core.download.DownloadManagerState;
 import com.biglybt.core.download.DownloadManagerStats;
+import com.biglybt.core.global.GlobalManager;
 import com.biglybt.core.logging.LogAlert;
 import com.biglybt.core.logging.Logger;
 import com.biglybt.core.networkmanager.LimitedRateGroup;
@@ -76,6 +77,9 @@ TagDownloadWithState
 	private boolean	fp_seeding;
 	private boolean fp_seeding_ever;
 	
+	private int		auto_sort_period;
+	private long	last_auto_sort	= -1;
+	
 	private boolean	supports_xcode;
 	private boolean	supports_file_location;
 
@@ -262,6 +266,8 @@ TagDownloadWithState
 		max_aggregate_share_ratio_priority	= readBooleanAttribute( AT_RATELIMIT_MAX_AGGREGATE_SR_PRIORITY, TagFeatureRateLimit.AT_RATELIMIT_MAX_AGGREGATE_SR_PRIORITY_DEFAULT );
 		fp_seeding							= readBooleanAttribute( AT_RATELIMIT_FP_SEEDING, false );
 
+		auto_sort_period					= getAutoApplySortInterval();
+		
 		notification_pub					= getNotifyMessageChannel();
 		
 		prevent_delete = getPreventDelete();
@@ -2204,6 +2210,8 @@ TagDownloadWithState
 		
 		checkNotifyPublish();
 		
+		checkSort();
+		
 		super.sync();
 	}
 
@@ -2317,29 +2325,31 @@ TagDownloadWithState
    	}
 
 	@Override
-	public void
+	public List<Taggable>
 	performOperation(
 		int		op )
 	{
-		performOperation( op, (t)->true );
+		return( performOperation( op, (t)->true ));
 	}
 	
 	@Override
-	public void
+	public List<Taggable>
 	performOperation(
 		int						op,
 		Predicate<Taggable>		filter )
 	{
 		Set<DownloadManager> dms = getTaggedDownloads();
 
-		performOperation( op, dms.stream().filter(filter) );
+		return( performOperation( op, dms.stream().filter(filter) ));
 	}
 
-	private void
+	private List<Taggable>
 	performOperation(
 		int					op,
 		Stream<DownloadManager> dms )
 	{
+		List<Taggable>	affected = new ArrayList<>();
+		
 		dms.forEach((dm)->{
 			int	dm_state = dm.getState();
 
@@ -2348,6 +2358,8 @@ TagDownloadWithState
 				if ( 	dm_state == DownloadManager.STATE_STOPPED ||
 						dm_state == DownloadManager.STATE_ERROR ){
 
+					affected.add( dm );
+					
 					rs_async.dispatch(
 						new AERunnable()
 						{
@@ -2360,12 +2372,16 @@ TagDownloadWithState
 						});
 				}else if ( dm.isForceStart()){
 					
+					affected.add( dm );
+					
 					rs_async.dispatch(()->{ dm.setForceStart( false ); });
 				}
 			}else if ( op == TagFeatureRunState.RSC_FORCE_START ){
 
 				if ( !dm.isForceStart()){
 
+					affected.add( dm );
+					
 					rs_async.dispatch(
 						new AERunnable()
 						{
@@ -2383,6 +2399,8 @@ TagDownloadWithState
 						dm_state != DownloadManager.STATE_STOPPING &&
 						dm_state != DownloadManager.STATE_ERROR ){
 
+					affected.add( dm );
+					
 					rs_async.dispatch(
 						new AERunnable()
 						{
@@ -2392,6 +2410,8 @@ TagDownloadWithState
 							{
 								dm.stopIt( DownloadManager.STATE_STOPPED, false, false );
 
+								dm.setStopReason( "Tag '" + getTagName() + "' stopped" );
+								
 									// recheck here in case it is an 'archive' action that requires
 									// download to be stopped
 
@@ -2405,6 +2425,8 @@ TagDownloadWithState
 						dm_state != DownloadManager.STATE_STOPPING &&
 						dm_state != DownloadManager.STATE_ERROR ){
 
+					affected.add( dm );
+					
 					rs_async.dispatch(
 						new AERunnable()
 						{
@@ -2413,6 +2435,8 @@ TagDownloadWithState
 							runSupport()
 							{
 								dm.pause( true );
+								
+								dm.setStopReason( "Tag '" + getTagName() + "' paused" );
 							}
 						});
 				}
@@ -2420,6 +2444,8 @@ TagDownloadWithState
 
 				if ( dm.isPaused()){
 
+					affected.add( dm );
+					
 					rs_async.dispatch(
 						new AERunnable()
 						{
@@ -2433,6 +2459,8 @@ TagDownloadWithState
 				}
 			}else{
 				
+				affected.add( dm );
+				
 				rs_async.dispatch(
 					new AERunnable()
 					{
@@ -2479,6 +2507,8 @@ TagDownloadWithState
 					});
 			}
 		});
+		
+		return( affected );
 	}
 
 	@Override
@@ -2907,4 +2937,227 @@ TagDownloadWithState
 		
 		return( result );
 	}
+	
+	@Override
+	public void 
+	setAutoApplySortInterval(
+		int secs)
+	{
+		super.setAutoApplySortInterval( secs );
+		
+		auto_sort_period = secs;
+	}
+	
+	private void
+	checkSort()
+	{
+		if ( auto_sort_period == 0 ){
+			
+			return;
+		}
+		
+		long now = SystemTime.getMonotonousTime();
+		
+		if ( last_auto_sort == -1 || now - last_auto_sort >= auto_sort_period*1000 ){
+			
+			if ( applySortSupport()){
+				
+				last_auto_sort = now;
+			}
+		}
+	}
+	
+	private boolean
+	applySortSupport()
+	{
+		try{
+			GlobalManager gm = CoreFactory.getSingleton().getGlobalManager();
+			
+			List<DownloadManager> downloads = new ArrayList<>( getTaggedDownloads());
+			
+			if ( downloads.isEmpty()){
+				
+				return( true );
+			}
+			
+			Collections.sort( downloads, (d1,d2)->{
+				return( Integer.compare( d1.getPosition(), d2.getPosition()));
+			});
+				
+			Long uid = getTagUID();
+			
+			List<Integer>	download_positions_comp 	= new ArrayList<>(downloads.size());
+			List<Integer>	download_positions_incomp 	= new ArrayList<>(downloads.size());
+			
+			List<Object[]>	tag_sort_comp 	= new ArrayList<>(downloads.size());
+			List<Object[]>	tag_sort_incomp = new ArrayList<>(downloads.size());
+			
+			String overall_options = null;
+			
+			for ( DownloadManager download: downloads ){
+				
+				Map<Long,Object[]> map = (Map<Long,Object[]>)download.getDownloadState().getTransientAttribute( DownloadManagerState.AT_TRANSIENT_TAG_SORT );
+				
+				Object[] entry = map==null?null:(Object[])map.get( uid );
+				
+				if ( entry == null ){
+					
+					// System.out.println( "tag sort missing for " + download.getDisplayName());
+					
+					return( false );
+				}
+				
+				if ( entry.length > 2 ){
+					
+					String options = (String)entry[2];
+					
+					if ( overall_options == null ){
+						
+						overall_options = options;
+						
+					}else{
+						
+						if ( options == null ){
+							
+							return( false );	// inconsistent
+							
+						}else{
+							
+							if ( !options.equals( overall_options )){
+								
+								return( false );	// inconsistent
+							}
+						}
+					}
+				}else{
+					
+					if ( overall_options != null ){
+						
+							// inconsistent
+						
+						return( false );
+					}
+				}
+				
+				int pos = download.getPosition();
+								
+				if ( download.isDownloadComplete(false)){
+				
+					download_positions_comp.add( pos );
+				
+					tag_sort_comp.add( new Object[]{ download, entry[1], pos, entry });
+
+				}else{
+					
+					download_positions_incomp.add( pos );
+					
+					tag_sort_incomp.add( new Object[]{ download, entry[1], pos, entry });
+				}
+			}
+			
+			Collections.sort( download_positions_comp );
+			
+			Collections.sort( download_positions_incomp );
+
+			boolean random = overall_options != null && overall_options.equals( "random" );
+			
+			if ( random  ){
+				
+				Collections.shuffle( tag_sort_comp );
+				
+				Collections.shuffle( tag_sort_incomp );
+				
+			}else{
+				
+				boolean reverse = overall_options != null && ( overall_options.equals( "r" ) || overall_options.equals( "reverse" ));
+				
+				Collections.sort( tag_sort_comp, (e1,e2)->{
+					if ( reverse ){
+						return(Long.compare((Long)e2[1],(Long)e1[1]));
+					}else{
+						return(Long.compare((Long)e1[1],(Long)e2[1]));
+					}
+				});
+				
+				Collections.sort( tag_sort_incomp, (e1,e2)->{
+					if ( reverse ){
+						return(Long.compare((Long)e2[1],(Long)e1[1]));
+					}else{
+						return(Long.compare((Long)e1[1],(Long)e2[1]));
+					}
+				});
+			}
+			
+			List<DownloadManager>	dms			= new ArrayList<>( download_positions_comp.size());
+			List<Integer>			positions	= new ArrayList<>( download_positions_comp.size());
+					
+			for ( int i=0;i<download_positions_comp.size();i++){
+				
+				int dl_pos = download_positions_comp.get(i);
+				
+				Object[] entry = tag_sort_comp.get(i);
+				
+				int current_pos = (Integer)entry[2];
+				
+				DownloadManager dm = (DownloadManager)entry[0];
+
+				if ( random ){
+					
+					((Object[])entry[3])[1] = (long)RandomUtils.nextInt( downloads.size());
+				}
+				
+				if ( current_pos != dl_pos ){
+					
+					dms.add( dm );
+					
+					positions.add( dl_pos );
+				}
+			}
+			
+			gm.moveTo( dms, positions );
+			
+			dms			= new ArrayList<>( download_positions_incomp.size());
+			positions	= new ArrayList<>( download_positions_incomp.size());
+
+			for ( int i=0;i<download_positions_incomp.size();i++){
+				
+				int dl_pos = download_positions_incomp.get(i);
+				
+				Object[] entry = tag_sort_incomp.get(i);
+				
+				int current_pos = (Integer)entry[2];
+				
+				DownloadManager dm = (DownloadManager)entry[0];
+				
+				if ( random ){
+					
+					((Object[])entry[3])[1] = (long)RandomUtils.nextInt( downloads.size());
+				}
+				
+				if ( current_pos != dl_pos ){
+					
+					dms.add( dm );
+					
+					positions.add( dl_pos );
+				}
+			}
+			
+			gm.moveTo( dms, positions );
+			
+			return( true );
+			
+		}catch( Throwable e ){
+			
+			Debug.out( e );
+			
+			return( false );
+		}
+	}
+	
+	@Override
+	public void 
+	applySort()
+	{
+		applySortSupport();
+	}
 }
