@@ -27,6 +27,7 @@ import java.net.URL;
 import java.util.Map;
 
 import com.biglybt.core.torrent.impl.TOTorrentCreateImpl;
+import com.biglybt.core.torrent.impl.TOTorrentCreateV2Impl;
 import com.biglybt.core.torrent.impl.TOTorrentCreatorImpl;
 import com.biglybt.core.torrent.impl.TOTorrentDeserialiseImpl;
 import com.biglybt.core.torrent.impl.TOTorrentImpl;
@@ -245,6 +246,15 @@ TOTorrentFactory
 		return( TOTorrentCreateImpl.getPieceCount( total_size, piece_size ));
 	}
 	
+	public static byte[]
+	getV2RootHash(
+		File		file )
+	
+		throws TOTorrentException
+	{
+		return( TOTorrentCreateV2Impl.getV2RootHash( file ));
+	}
+	
 	public static void
 	addTorrentListener(
 		TOTorrentListener		listener )
