@@ -24,6 +24,7 @@ import java.net.URL;
 import java.util.*;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentLinkedDeque;
+import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 
 import com.biglybt.core.Core;
@@ -47,6 +48,7 @@ import com.biglybt.core.tracker.AllTrackersManager.ScrapeStats;
 import com.biglybt.core.tracker.AllTrackersManager.ScrapeStatsProvider;
 import com.biglybt.core.tracker.client.TRTrackerAnnouncerRequest;
 import com.biglybt.core.tracker.client.TRTrackerAnnouncerResponse;
+import com.biglybt.core.tracker.client.TRTrackerAnnouncerResponsePeer;
 import com.biglybt.core.tracker.client.TRTrackerScraperResponse;
 import com.biglybt.core.util.AERunnable;
 import com.biglybt.core.util.Average;
@@ -359,6 +361,15 @@ AllTrackersManagerImpl
 								updated = true;
 							}
 		
+							TRTrackerAnnouncerResponsePeer[] peers = a_resp.getPeers();
+
+								// assume if one cached they are all cached in this response
+							
+							if ( peers != null && peers.length > 0 && !peers[0].isCached()){
+
+								tracker.peersReceived( peers.length );
+							}
+							
 							if ( updated ){
 								
 								tracker.log( a_resp );
@@ -516,9 +527,9 @@ AllTrackersManagerImpl
 			boolean skip_unregistered = closing && got_running;
 			
 			try{
-				Map map = new HashMap();
+				Map<String,Object> map = new HashMap<>();
 				
-				List<Map>	trackers = new ArrayList<>( host_map.size() + 32 );
+				List<Map<String,Object>>	trackers = new ArrayList<>( host_map.size() + 32 );
 				
 				map.put( "trackers", trackers ); 
 				
@@ -526,7 +537,36 @@ AllTrackersManagerImpl
 				
 					if ( skip_unregistered && !tracker.isRegistered()){
 						
-						continue;
+							// retain if it has non-default options
+						
+						Map<String,Object> options = tracker.getOptions();
+						
+						boolean has_non_def = false;
+						
+						if ( options != null ){
+							
+							for ( String opt: AllTrackersTracker.OPT_ALL ){
+								
+								try{
+									Number num = (Number)options.get( opt );
+									
+									if ( num != null && num.intValue() != 0 ){
+										
+										has_non_def = true;
+										
+										break;
+									}
+								}catch( Throwable e ){
+									
+									Debug.out( e );
+								}
+							}
+						}
+						
+						if ( !has_non_def ){
+						
+							continue;
+						}
 					}
 					
 					try{
@@ -547,13 +587,13 @@ AllTrackersManagerImpl
 				
 				if ( !logging_keys.isEmpty()){
 					
-					List<Map>	logging = new ArrayList<>( logging_keys.size() + 32 );
+					List<Map<String,String>>	logging = new ArrayList<>( logging_keys.size() + 32 );
 					
 					map.put( "logging", logging ); 
 					
 					for ( String key: logging_keys.keySet()){
 						
-						Map m = new HashMap();
+						Map<String,String> m = new HashMap<>();
 						
 						logging.add( m );
 						
@@ -655,6 +695,15 @@ AllTrackersManagerImpl
 		TRTrackerAnnouncerRequest	request )
 	{
 		active_requests.put( request, "" );
+		
+		String key = ingestURL( request.getURL());
+		
+		AllTrackersTrackerImpl tracker = host_map.get( key );
+		
+		if ( tracker != null ){
+			
+			tracker.addActiveRequest();
+		}
 	}
 		
 	@Override
@@ -665,6 +714,15 @@ AllTrackersManagerImpl
 		active_requests.remove( request );
 		
 		announce_rate.addValue( 100 );
+		
+	String key = ingestURL( request.getURL());
+		
+		AllTrackersTrackerImpl tracker = host_map.get( key );
+		
+		if ( tracker != null ){
+			
+			tracker.removeActiveRequest();
+		}
 	}
 	
 	@Override
@@ -1281,6 +1339,10 @@ AllTrackersManagerImpl
 		
 		private LoggerChannel	logger;
 		
+		private long			peers_received;		// not persisted
+		
+		private AtomicInteger	active_request_count = new AtomicInteger();
+		
 		private MovingImmediateAverage	request_average = AverageFactory.MovingImmediateAverage( 5 );
 		
 		private
@@ -1381,7 +1443,7 @@ AllTrackersManagerImpl
 			logger = logging_keys.get( short_key );
 		}
 		
-		private Map
+		private Map<String,Object>
 		exportToMap()
 		{
 			Map<String,Object>	map = new HashMap<>();
@@ -1478,6 +1540,25 @@ AllTrackersManagerImpl
 			return( num_private + num_public );
 		}
 		
+		@Override
+		public int
+		getActiveRequestCount()
+		{
+			return( active_request_count.get());
+		}
+		
+		protected void
+		addActiveRequest()
+		{
+			active_request_count.incrementAndGet();
+		}
+		
+		protected void
+		removeActiveRequest()
+		{
+			active_request_count.decrementAndGet();
+		}
+		
 		@Override
 		public boolean 
 		isRemovable()
@@ -1485,6 +1566,20 @@ AllTrackersManagerImpl
 			return( getTorrentCount() == 0 );
 		}
 		
+		private void
+		peersReceived(
+			int		num )
+		{
+			peers_received += num;
+		}
+		
+		@Override
+		public long 
+		getPeersReceived()
+		{
+			return( peers_received );
+		}
+		
 		@Override
 		public void 
 		remove()
