@@ -688,10 +688,15 @@ TRHostImpl
 				@Override
 				public void
 				receivedTrackerResponse(
+					TRTrackerAnnouncerRequest	request,
 					TRTrackerAnnouncerResponse	response	)
 				{
 					try{
-						TRTrackerScraperFactory.getSingleton().scrape( torrent, true );
+							// Changed this to not force an actual scrape as we will have updated
+							// the scrape value in the announce-code already and a synchronous forced scrape
+							// can block things for a while and creates unnecessary load
+						
+						TRTrackerScraperFactory.getSingleton().scrape( torrent, false );
 
 					}finally{
 
@@ -915,6 +920,21 @@ TRHostImpl
 		}
 	}
 
+	@Override
+	public int 
+	getTorrentCount()
+	{
+		try{
+			this_mon.enter();
+			
+			return( host_torrents.size());
+			
+		}finally{
+
+			this_mon.exit();
+		}
+	}
+	
 	@Override
 	public void
 	clientCreated(
