@@ -20,6 +20,7 @@ package com.biglybt.core.util;
 import java.io.InputStreamReader;
 import java.io.LineNumberReader;
 import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
 import java.util.Locale;
 import java.util.StringTokenizer;
 import java.util.TimeZone;
@@ -72,8 +73,8 @@ Constants
 
 	public static final String[] APP_DOMAINS = { "azureusplatform.com", "azureus.com", "aelitis.com", "vuze.com", "biglybt.com" };
 
-	public static final Charset UTF_8 = Charset.forName("UTF-8");
-	public static final Charset ISO_8859_1 = Charset.forName("ISO-8859-1");
+	public static final Charset UTF_8		= StandardCharsets.UTF_8; 		// Charset.forName("UTF-8");
+	public static final Charset ISO_8859_1	= StandardCharsets.ISO_8859_1;	// Charset.forName("ISO-8859-1");
 
 	@Deprecated
 	public static final String DEFAULT_ENCODING 	= "UTF8";
@@ -144,26 +145,28 @@ Constants
 	public static final String BIGLY_PEER_ID						= "BI";
 
 	
-	public static final String BIGLYBT_VERSION  = "3.2.0.0";
+	public static final String BIGLYBT_VERSION  = "3.4.0.0";
 	
 	//public static final String BUILD_VERSION  = "@build.version@";   //Ant replace - believed dead
 	public static final String SUBVERSION		= "";
-	public static final byte[] VERSION_ID       = ("-" + BIGLY_PEER_ID + "3200" + "-").getBytes();  //MUST be 8 chars long!
+	public static final byte[] VERSION_ID       = ("-" + BIGLY_PEER_ID + "3400" + "-").getBytes();  //MUST be 8 chars long!
 
 	private static final boolean FORCE_NON_CVS = System.getProperty( "az.force.noncvs", "0" ).equals( "1" );
 
 	public static final boolean IS_CVS_VERSION = isCVSVersion( BIGLYBT_VERSION ) && !FORCE_NON_CVS;
 
-	public static final String  OSName = System.getProperty("os.name");
+	public static final String  OSName 		= System.getProperty("os.name","");
+	public static final String  OSArch 		= System.getProperty("os.arch","");
+	public static final String  OSVersion	= System.getProperty("os.version","");
 
-	public static final boolean isOSX				= OSName.toLowerCase().startsWith("mac os");
+	public static final boolean isOSX			= OSName.toLowerCase().startsWith("mac os");
 	public static final boolean isLinux			= OSName.equalsIgnoreCase("Linux");
-	public static final boolean isSolaris			= OSName.equalsIgnoreCase("SunOS");
-	public static final boolean isFreeBSD			= OSName.equalsIgnoreCase("FreeBSD");
+	public static final boolean isSolaris		= OSName.equalsIgnoreCase("SunOS");
+	public static final boolean isFreeBSD		= OSName.equalsIgnoreCase("FreeBSD");
 	public static final boolean isWindowsXP		= OSName.equalsIgnoreCase("Windows XP");
 	public static final boolean isWindows95		= OSName.equalsIgnoreCase("Windows 95");
 	public static final boolean isWindows98		= OSName.equalsIgnoreCase("Windows 98");
-	public static final boolean isWindows2000		= OSName.equalsIgnoreCase("Windows 2000");
+	public static final boolean isWindows2000	= OSName.equalsIgnoreCase("Windows 2000");
 	public static final boolean isWindowsME		= OSName.equalsIgnoreCase("Windows ME");
 	public static final boolean isWindows9598ME	= isWindows95 || isWindows98 || isWindowsME;
 
@@ -182,6 +185,9 @@ Constants
 	// public static final boolean isWindows11OrHigher;   BORKED
 
 
+
+	public static final boolean isArm = OSArch.startsWith("arm") || OSArch.startsWith("aarch");
+    
 	public static final boolean is64Bit;
 	public static final boolean isOS64Bit;
 
@@ -189,7 +195,7 @@ Constants
 		boolean _is64Bit;
 
 		try{
-			_is64Bit = System.getProperty( "os.arch" ).contains( "64" );
+			_is64Bit = OSArch.contains( "64" );
 
 			if ( !_is64Bit ){
 
@@ -223,7 +229,7 @@ Constants
 			Float ver = null;
 
 			try{
-				ver = new Float( System.getProperty( "os.version" ));
+				ver = new Float(OSVersion);
 
 			}catch (Throwable e){
 			}
@@ -335,7 +341,7 @@ Constants
 			int	second_digit	= 0;
 
 			try{
-				String os_version = System.getProperty( "os.version" );
+				String os_version = OSVersion;
 
 				String[] bits = os_version.split( "\\." );
 
@@ -393,6 +399,7 @@ Constants
 	public static final boolean isJava10OrHigher;
 	public static final boolean isJava11OrHigher;
 	public static final boolean isJava12OrHigher;
+	public static final boolean isJava18OrHigher;
 
 	static{
 		// http://www.oracle.com/technetwork/java/javase/versioning-naming-139433.html
@@ -407,6 +414,7 @@ Constants
 		boolean	_10plus;
 		boolean	_11plus;
 		boolean	_12plus;
+		boolean	_18plus;
 
 		try{
 			// from Java 9 we need to drop stuff after a + or - as we can have 9-ea (well, the + case shouldn't occur in java.version but whatever)
@@ -431,6 +439,7 @@ Constants
 			_10plus = first >= 10;
 			_11plus = first >= 11;
 			_12plus = first >= 12;
+			_18plus = first >= 18;
 
 		}catch( Throwable e ){
 
@@ -443,6 +452,7 @@ Constants
 			_10plus = false;
 			_11plus = false;
 			_12plus = false;
+			_18plus = false;
 		}
 
 		isJava8OrHigher		= _8plus;
@@ -450,6 +460,7 @@ Constants
 		isJava10OrHigher	= _10plus;
 		isJava11OrHigher	= _11plus;
 		isJava12OrHigher	= _12plus;
+		isJava18OrHigher	= _18plus;
 	}
 
 	public static final String	FILE_WILDCARD = isWindows?"*.*":"*";
