@@ -141,6 +141,13 @@ public class FileUtil {
 			}
 		}
 		fileHandling = fileHandlingImpl == null ? new FileHandler() : fileHandlingImpl;
+		
+		AEThread2.createAndStartDaemon( "FileUtil:init", ()->{
+			
+				// grab initial file roots
+			
+			listRootsWithTimeout();
+		});
 	}
 
   public static boolean
@@ -3484,6 +3491,19 @@ public class FileUtil {
 		log( str, null );
 	}
 	
+	public static void
+	log(
+		String		str,
+		boolean		addLocation )
+	{
+		if ( addLocation ){
+			
+			str += ": " + Debug.getStackTrace( true, false );
+		}
+		
+		log( str, null );
+	}
+	
 	public static void
 	log(
 		String		str, 
@@ -3509,6 +3529,29 @@ public class FileUtil {
 		}
 	}
 	
+	public static String
+	removeTrailingSeparators(
+		String 	str )
+	{
+			// on Windows we don't want C:\ to be turned into C:
+			// not sure if there are implications for UNC \\server style paths
+			// or ones including ~ on linux...
+		
+		int min_length = 1;
+		
+		if ( Constants.isWindows && str.length() > 2 && str.charAt(1)== ':' ){
+			
+			min_length = 3;
+		}
+		
+		while( str.endsWith( File.separator ) && str.length() > min_length ){
+			
+			str = str.substring(0, str.length()-1 );
+		}
+		
+		return( str );
+	}
+	
 		/**
 		 * Gets the encoding that should be used when writing script files (currently only
 		 * tested for windows as this is where an issue can arise...)
@@ -3562,7 +3605,7 @@ public class FileUtil {
 
 		// when a file is on an unavailable network share (for example) then this can trash the UI by hanging the SWT thread.
 	
-	private static Set<Path>		bad_roots = new HashSet<>();
+	private static Map<Path,int[]>		bad_roots = new HashMap<>();
 	
 	interface
 	FileOpWithTimeout<T>
@@ -3623,7 +3666,7 @@ public class FileUtil {
 				
 				Path root_path = file.toPath().getRoot();
 
-				if ( bad_roots.contains( root_path )){
+				if ( bad_roots.containsKey( root_path )){
 				
 					if ( def_error == null ){
 						
@@ -3652,7 +3695,7 @@ public class FileUtil {
 				
 				synchronized( bad_roots ){
 					
-					if ( !bad_roots.contains(root_path)){
+					if ( !bad_roots.containsKey(root_path)){
 				
 						if ( bad_roots.size() > 1024 ){
 							
@@ -3660,7 +3703,7 @@ public class FileUtil {
 							
 						}else{
 							
-							bad_roots.add(root_path);
+							bad_roots.put(root_path, new int[]{0});
 							
 							if ( bad_roots.size() == 1 ){
 								
@@ -3668,45 +3711,96 @@ public class FileUtil {
 									
 									while( true ){								
 										try{
-											Thread.sleep( 5000 );
+											Thread.sleep( 30*1000 );
 											
 										}catch( Throwable e ){
 											
 										}
 										
-										List<Path> to_check;
+										Map<Path, int[]> to_check;
 										
 										synchronized( bad_roots ){
 											
-											to_check = new ArrayList<Path>( bad_roots );										
+											to_check = new HashMap<>( bad_roots );										
 										}
 										
-										for ( Path path: to_check ){
+										for ( Map.Entry<Path,int[]> entry: to_check.entrySet()){
 											
 											try{
-												long check_start = SystemTime.getCurrentTime();
+												long check_start = SystemTime.getMonotonousTime();
 												
-												File check_file = path.toFile();
+												int limit = 250;
 												
-												check_file.getCanonicalPath();
-												
-												check_file.exists();
-												
-												check_file.length();
-												
-												if ( SystemTime.getCurrentTime() - check_start < 250 ){
-													
-													Debug.out( "Root path " + root_path + " appears to be responding in a timely manner, enabling" );
-													
-													synchronized( bad_roots ){
+												Path	path	= entry.getKey();
+												int[]	oks		= entry.getValue();
 														
-														bad_roots.remove( path );
-														
-														if ( bad_roots.isEmpty()){
+												File 	check_file	= path.toFile();
+outer:
+												for ( int i=0;; i++){
+													
+													switch(i){
+														case 0:{
+															check_file.getCanonicalPath();
+															break;
+														}
+														case 1:{
+															check_file.exists();
+															break;
+														}
+														case 2:{
+															check_file.length();
+															break;
+														}
+														case 3:{
+															check_file.isDirectory();
+															break;
+														}
+														case 4:{
+															File random_file = new File( check_file, "Test" + RandomUtils.nextAbsoluteLong() + ".dat" );
+
+															if ( random_file.isFile()){
 															
-															return;
+																Thread.sleep(limit);
+															}
+															
+															break;
+														}
+														case 5:{
+															check_file.listFiles();
+															break;
+														}
+														default:{
+															break outer;
 														}
 													}
+													
+													if ( SystemTime.getMonotonousTime() - check_start >= limit ){
+														
+														break;
+													}
+												}												
+												
+												if ( SystemTime.getMonotonousTime() - check_start < limit ){
+													
+													oks[0]++;
+													
+													if ( oks[0] > 2 ){
+														
+														Debug.out( "Root path " + path + " appears to be responding in a timely manner, enabling" );
+														
+														synchronized( bad_roots ){
+															
+															bad_roots.remove( path );
+															
+															if ( bad_roots.isEmpty()){
+																
+																return;
+															}
+														}
+													}
+												}else{
+													
+													oks[0] = 0;
 												}
 											}catch( Throwable e ){
 												
@@ -3771,6 +3865,64 @@ public class FileUtil {
 		}, new IOException( "File system not responding/slow" )));	
 	}
 	
+	private static volatile File[]	last_roots = {};
+	private static long				last_roots_time = -1;
+	
+    private static AsyncDispatcher	root_updater = new AsyncDispatcher( "RootUpdater" );
+    private static AESemaphore		root_update_sem;
+    
+	public static File[]
+	listRootsWithTimeout()
+	{	
+		long now = SystemTime.getMonotonousTime();
+		
+		AESemaphore sem;
+		
+		synchronized( root_updater ){
+		
+			if ( last_roots_time != -1 && now - last_roots_time < 10*1000 ){
+								
+				return( last_roots );
+			}
+			
+			sem = root_update_sem;
+			
+			if ( sem == null ){
+				
+				last_roots_time = now;
+				
+				sem = root_update_sem = new AESemaphore( "RootUpdate" );
+				
+				root_updater.dispatch(()->{
+					
+					try{
+							// this can take a while if network shares are disconnected (for example)
+						
+						File[] roots = File.listRoots();
+						
+						if ( roots != null ){
+							
+							last_roots = roots;
+						}
+					}finally{
+					
+						synchronized( root_updater ){
+						
+						
+							root_update_sem.releaseForever();
+							
+							root_update_sem = null;
+						}
+					}
+				});
+			}
+		}
+		
+		sem.reserve( 250 );
+		
+		return( last_roots );
+	}
+	
 	public interface
 	ProgressListener
 	{
