@@ -1513,8 +1513,8 @@ public class VersionCheckClient {
 		
 		message.put( "ui",      COConfigurationManager.getStringParameter( "ui", "unknown" ) );
 		message.put( "os",      Constants.OSName );
-		message.put( "os_version", System.getProperty( "os.version" ) );
-		message.put( "os_arch", System.getProperty( "os.arch" ) );   //see http://lopica.sourceforge.net/os.html
+		message.put( "os_version", Constants.OSVersion );
+		message.put( "os_arch", Constants.OSArch );   //see http://lopica.sourceforge.net/os.html
 		message.put( "os_arch_dm", System.getProperty( "sun.arch.data.model" ) );  // might be needed to openjdk on osx
 
 		boolean using_phe = COConfigurationManager.getBooleanParameter( "network.transport.encrypted.require" );
