@@ -139,9 +139,10 @@ DiskManagerFileInfoImpl
 	@Override
 	public void
 	setLink(
-		File	link_destination )
+		File		link_destination,
+		boolean		no_delete )
 	{
-		core.setLink( link_destination );
+		core.setLink( link_destination, no_delete );
 	}
 
 	@Override
