@@ -561,10 +561,11 @@ PeerImpl
 	public void
 	close(
 		String 		reason,
+		int			reason_code,
 		boolean 	closedOnError,
 		boolean 	attemptReconnect )
 	{
-		manager.removePeer( this, reason );
+		manager.removePeer( this, reason, reason_code );
 	}
 
 	@Override
@@ -627,17 +628,17 @@ PeerImpl
 	}
 
 	@Override
-	public int
-	getPercentDoneOfCurrentIncomingRequest()
+	public int[]
+	getCurrentIncomingRequestProgress()
 	{
-		return( delegate.getPercentDoneOfCurrentIncomingRequest());
+		return( delegate.getCurrentIncomingRequestProgress());
 	}
 
 	@Override
-	public int
-	getPercentDoneOfCurrentOutgoingRequest()
+	public int[]
+	getCurrentOutgoingRequestProgress()
 	{
-		return( delegate.getPercentDoneOfCurrentOutgoingRequest());
+		return( delegate.getCurrentOutgoingRequestProgress());
 	}
 
 
