@@ -783,6 +783,18 @@ outer:
 		final byte							flags,
 		final boolean						high_priority,
 		final DHTPluginOperationListener	listener)
+	{
+		putEx( key, description, value, (short)(flags&0x00ff), high_priority, listener );
+	}
+	
+	public void
+	putEx(
+		final byte[]						key,
+		final String						description,
+		final byte[]						value,
+		final short							flags,
+		final boolean						high_priority,
+		final DHTPluginOperationListener	listener)
 	{
 		dht.put( 	key,
 					description,
@@ -1035,12 +1047,14 @@ outer:
 
 	public void
 	remove(
-		final byte[]						key,
-		final String						description,
-		final DHTPluginOperationListener	listener )
+		byte[]						key,
+		String						description,
+		short						flags,
+		DHTPluginOperationListener	listener )
 	{
 		dht.remove( 	key,
 						description,
+						flags,
 						new DHTOperationListener()
 						{
 							private boolean started;
