@@ -271,7 +271,7 @@ ExternalSeedPeer
 			listeners_mon.exit();
 		}
 
-		manager.removePeer( this );
+		manager.removePeer( this, "Deactivating", com.biglybt.core.networkmanager.Transport.CR_STOPPED_OR_REMOVED );
 
 		setState( Peer.DISCONNECTED );
 	}
@@ -575,7 +575,7 @@ ExternalSeedPeer
 	}
 
 	@Override
-	public List
+	public List<PeerReadRequest>
 	getExpiredRequests()
 	{
 		return( reader.getExpiredRequests());
@@ -694,6 +694,7 @@ ExternalSeedPeer
 	public void
 	close(
 		String 		reason,
+		int			reason_code,
 		boolean 	closedOnError,
 		boolean 	attemptReconnect )
 	{
@@ -730,7 +731,7 @@ ExternalSeedPeer
 
 		if ( peer_was_added ){
 
-			manager.removePeer( this );
+			manager.removePeer( this, reason, reason_code );
 		}
 
 		setState( Peer.DISCONNECTED );
@@ -916,10 +917,10 @@ ExternalSeedPeer
 	}
 
 	@Override
-	public int
-	getPercentDoneOfCurrentIncomingRequest()
+	public int[]
+	getCurrentIncomingRequestProgress()
 	{
-		return( reader.getPercentDoneOfCurrentIncomingRequest());
+		return( reader.getCurrentIncomingRequestProgress());
 	}
 
 	@Override
@@ -938,10 +939,10 @@ ExternalSeedPeer
 
 
 	@Override
-	public int
-	getPercentDoneOfCurrentOutgoingRequest()
+	public int[]
+	getCurrentOutgoingRequestProgress()
 	{
-		return( 0 );
+		return( null );
 	}
 
 	public Map
@@ -1029,7 +1030,7 @@ ExternalSeedPeer
 				public void notifyOfExternalSend(Message message ){}
 
 				@Override
-				public int getPercentDoneOfCurrentMessage(){ return( -1 );}
+				public int[] getCurrentMessageProgress(){ return( null );}
 
 				@Override
 				public int getDataQueuedBytes(){ return( 0 ); }
@@ -1057,7 +1058,7 @@ ExternalSeedPeer
 				public void notifyOfExternalReceive(Message message ){}
 
 				@Override
-				public int getPercentDoneOfCurrentMessage(){ return( ExternalSeedPeer.this.getPercentDoneOfCurrentIncomingRequest()); }
+				public int[] getCurrentMessageProgress(){ return( ExternalSeedPeer.this.getCurrentIncomingRequestProgress()); }
 			};
 
 		@Override
