@@ -2634,6 +2634,7 @@ BuddyPluginNetwork
 
 		private AsyncDispatcher	publish_dispatcher = new AsyncDispatcher();
 
+		private boolean 	ygm_active;
 		private boolean		bogus_ygm_written;
 
 		private int		status_seq;
@@ -2837,13 +2838,25 @@ BuddyPluginNetwork
 		private void
 		checkMessagePending()
 		{
+			synchronized( this ){
+				
+				if ( ygm_active ){
+					
+					return;
+				}
+				
+				ygm_active = true;
+			}
+			
+			boolean active = false;
+			
 			try{
 				String	reason = "Friend YGM check";
 
 				byte[] public_key = ecc_handler.getPublicKey( reason );
 
 				DistributedDatabaseKey	key = getYGMKey( public_key, reason );
-
+				
 				ddb.read(
 					new DistributedDatabaseListener()
 					{
@@ -2927,6 +2940,11 @@ BuddyPluginNetwork
 							}else if ( 	type == DistributedDatabaseEvent.ET_OPERATION_TIMEOUT ||
 										type == DistributedDatabaseEvent.ET_OPERATION_COMPLETE ){
 
+								synchronized( DDBDetails.this ){
+									
+									ygm_active = false;
+								}
+								
 								if ( new_ygm_buddies.size() > 0 || unauth_permitted ){
 
 									BuddyPluginBuddy[] b = new BuddyPluginBuddy[new_ygm_buddies.size()];
@@ -2942,6 +2960,8 @@ BuddyPluginNetwork
 					120*1000,
 					DistributedDatabase.OP_EXHAUSTIVE_READ );
 
+				active = true;
+
 				boolean	write_bogus_ygm = false;
 
 				synchronized( this ){
@@ -2985,6 +3005,16 @@ BuddyPluginNetwork
 			}catch( Throwable e ){
 
 				logMessage( null, "YGM check failed", e );
+				
+			}finally{
+				
+				if ( !active ){
+					
+					synchronized( this ){
+							
+						ygm_active = false;
+					}
+				}
 			}
 		}
 		
