@@ -48,7 +48,6 @@ import com.biglybt.core.tag.TagType;
 import com.biglybt.core.torrent.TOTorrent;
 import com.biglybt.core.torrent.TOTorrentFactory;
 import com.biglybt.core.torrent.TOTorrentFile;
-import com.biglybt.core.torrent.TOTorrentFileHashTree;
 import com.biglybt.core.util.*;
 import com.biglybt.pif.PluginException;
 import com.biglybt.pif.PluginInterface;
@@ -517,14 +516,10 @@ SimpleAPIPlugin
 					
 					if ( !is_pad ){
 					
-						TOTorrentFileHashTree tree = t_file.getHashTree();
+						root_hash = t_file.getRootHash();
 
-						if ( tree != null ){
-							
-							root_hash = tree.getRootHash();
-							
-						}else{
-						
+						if ( root_hash == null ){
+													
 							if ( calc_root_hashes && size > 0 && size == downloaded && data_file.length() == size && !t_file.isPadFile()){
 							
 								String key = String.valueOf( index );
@@ -942,6 +937,12 @@ SimpleAPIPlugin
 				
 				Logger.log( alert );
 				
+			}else if ( method.equals( "playsound" )){
+				
+				String optional_file	= args.get( "file" );
+				
+				GeneralUtils.playSound( optional_file );
+				
 			}else if ( 	method.equals( "markresultsread" ) ||  
 						method.equals( "markallresultsread" ) ||	// remove this post 3101_B02
 						method.equals( "markresultsreadinall")){
