@@ -182,8 +182,13 @@ public class ConfigSectionLogging
 		// Param still in use.. not sure why it's commented out
 //		BooleanParameterImpl udp_transport = new BooleanParameterImpl(config, "Logging Enable UDP Transport", "ConfigView.section.logging.udptransport");
 		
-		if ( !Constants.IS_CVS_VERSION ){
+		if ( Constants.IS_CVS_VERSION ){
 			
+			BooleanParameterImpl force_debug = new BooleanParameterImpl(
+					BCFG_LOGGER_DEBUG_FILES_DISABLE, "ConfigView.section.logging.disabledebugfiles");
+			
+			add(force_debug);
+		}else{
 				// beta versions already have the debug files forced
 			
 			BooleanParameterImpl force_debug = new BooleanParameterImpl(
@@ -192,6 +197,7 @@ public class ConfigSectionLogging
 			add(force_debug);
 		}
 		
+		
 		add(new IntParameterImpl(ICFG_LOGGER_DEBUG_FILES_SIZE_KB,
 				"ConfigView.section.logging.debugfilesize", 10, Integer.MAX_VALUE),
 				Parameter.MODE_INTERMEDIATE);
