@@ -168,8 +168,29 @@ BuddyPluginView
 		
 		ui_instance.registerView(UISWTInstance.VIEW_MAIN,
 				ui_instance.createViewBuilder(
-						FriendsView.VIEW_ID).setListenerInstantiator(true,
-					(Builder, swtView) -> new FriendsView(this, plugin, ui_instance)));
+						FriendsView.VIEW_ID).setListenerInstantiator(
+							new UISWTViewBuilder.UISWTViewEventListenerInstantiator()
+							{
+								@Override
+								public boolean
+								supportsMultipleViews()
+								{
+									return( true );
+								}
+								
+								public UISWTViewEventListener 
+								createNewInstance(UISWTViewBuilder Builder, UISWTView forView) throws Exception
+								{
+									return( new FriendsView(BuddyPluginView.this, plugin, ui_instance));
+								}
+								@Override
+								public String 
+								getUID()
+								{
+									return( FriendsView.VIEW_ID );
+								}
+							}));
+					
 
 		checkBetaInit();
 	}
@@ -966,8 +987,32 @@ BuddyPluginView
 
 			// Our one listener instance can handle multiple views, so we
 			// return same listener for every instantiation
-			UISWTViewBuilder viewBuilder = ui_instance.createViewBuilder(
-					VIEWID_CHAT).setListenerInstantiator(true, (Builder, view) -> listener);
+				
+			UISWTViewBuilder viewBuilder = 
+				ui_instance.createViewBuilder(
+					VIEWID_CHAT).setListenerInstantiator(
+						new UISWTViewBuilder.UISWTViewEventListenerInstantiator()
+						{
+							@Override
+							public boolean
+							supportsMultipleViews()
+							{
+								return( true );
+							}
+							
+							@Override
+							public UISWTViewEventListener createNewInstance(UISWTViewBuilder Builder, UISWTView forView)
+									throws Exception{
+								
+								return listener;
+							}
+							
+							@Override
+							public String getUID(){
+								return( VIEWID_CHAT );
+							}
+						});
+			
 			for (Class datasourceType : datasourceTypes) {
 				ui_instance.registerView(datasourceType, viewBuilder);
 			}
@@ -2184,7 +2229,7 @@ BuddyPluginView
 
 				// left
 
-				lhs = new Group( composite, SWT.NULL );
+				lhs = Utils.createSkinnedGroup( composite, SWT.NULL );
 				lhs.setText( MessageText.getString( "label.chat.type" ));
 				layout = new GridLayout();
 				layout.numColumns = 1;
@@ -2222,7 +2267,7 @@ BuddyPluginView
 
 					// middle
 
-				middle = new Group( composite, SWT.NULL );
+				middle = Utils.createSkinnedGroup( composite, SWT.NULL );
 				layout = new GridLayout();
 				layout.numColumns = 1;
 				middle.setLayout(layout);
@@ -2485,9 +2530,9 @@ BuddyPluginView
 
 						Set<String> trackers = new HashSet<>();
 
-						if ( current_download != null ){
+						if ( download != null ){
 
-							DownloadManager core_dm = current_download.getCoreDownload();
+							DownloadManager core_dm = download.getCoreDownload();
 
 							if ( core_dm != null ){
 
@@ -2584,13 +2629,13 @@ BuddyPluginView
 
 						List<Tag> tags;
 
-						if ( current_download == null ){
+						if ( download == null ){
 
 							tags = new ArrayList<>();
 
 						}else{
 
-							DownloadManager core_dm = current_download.getCoreDownload();
+							DownloadManager core_dm = download.getCoreDownload();
 
 							if ( core_dm == null ){
 
@@ -3140,6 +3185,20 @@ BuddyPluginView
 
 					chat_composite.setData( comp_key );
 
+					GridLayout layout = new GridLayout();
+					layout.numColumns = 1;
+					chat_composite.setLayout(layout);
+
+					Label label = new Label( chat_composite, SWT.NULL );
+
+					label.setText( MessageText.getString( "azbuddy.os_not_avail" ));
+					
+					GridData grid_data = new GridData(GridData.FILL_BOTH );
+					
+					label.setLayoutData(grid_data);
+					
+					chat_composite.layout( true, true );
+					
 					return;
 				}
 
