@@ -54,6 +54,7 @@ import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.mdi.MultipleDocumentInterfaceSWT;
 import com.biglybt.ui.swt.pifimpl.UISWTViewBuilderCore;
 import com.biglybt.ui.swt.shells.MessageBoxShell;
+import com.biglybt.ui.swt.shells.PopOutManager;
 import com.biglybt.ui.swt.skin.SWTSkinObject;
 import com.biglybt.ui.swt.skin.SWTSkinObjectTextbox;
 import com.biglybt.ui.swt.views.skin.InfoBarUtil;
@@ -197,6 +198,28 @@ public class SBC_ChatOverview
 		}
 	}
 	
+	public static void
+	popOutChat(
+		String		network,
+		String		key,
+		boolean		on_top )
+	{
+		BuddyPluginBeta beta = BuddyPluginUtils.getBetaPlugin();
+
+		if ( beta != null ){
+
+			try{
+				ChatInstance chat = beta.getChat(network, key);
+
+				popOutChat( chat, on_top );
+				
+			}catch( Throwable e ){
+
+				Debug.out( e );
+			}
+		}
+	}
+	
 	public static void
 	openChat(
 		ChatInstance		chat )
@@ -216,6 +239,31 @@ public class SBC_ChatOverview
 		}
 	}
 	
+	public static void
+	popOutChat(
+		ChatInstance		chat,
+		boolean				on_top )
+	{
+		try{
+			chat.setAutoNotify( true );
+
+			MultipleDocumentInterface mdi = UIFunctionsManager.getUIFunctions().getMDI();
+
+			if ( mdi != null ){
+
+				Map<String,Object> options = new HashMap<>();
+				
+				options.put( PopOutManager.OPT_ON_TOP, on_top );
+				options.put( PopOutManager.OPT_CAN_MINIMIZE, true );
+				
+				mdi.popoutEntryByID("Chat_", chat, options );
+			}
+		}catch( Throwable e ){
+
+			Debug.out( e );
+		}
+	}
+	
 	private static MdiEntry
 	createChatMdiEntry(
 		UIManager		ui_manager,
@@ -489,6 +537,22 @@ public class SBC_ChatOverview
 					}
 				});
 
+		tableManager.registerColumn(ChatInstance.class, ColumnChatSaveMessages.COLUMN_ID,
+				new TableColumnCreationListener() {
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnChatSaveMessages(column);
+					}
+				});
+
+		tableManager.registerColumn(ChatInstance.class, ColumnChatLogMessages.COLUMN_ID,
+				new TableColumnCreationListener() {
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnChatLogMessages(column);
+					}
+				});
+
 		tableManager.setDefaultColumnNames(TABLE_CHAT,
 			new String[] {
 
@@ -597,8 +661,8 @@ public class SBC_ChatOverview
 			}
 			tv.setRowDefaultHeightEM(1);
 
-			table_parent = new Composite(control, SWT.BORDER);
-			table_parent.setLayoutData(Utils.getFilledFormData());
+			table_parent = Utils.createSkinnedComposite(control, SWT.BORDER, Utils.getFilledFormData());
+		
 			GridLayout layout = new GridLayout();
 			layout.marginHeight = layout.marginWidth = layout.verticalSpacing = layout.horizontalSpacing = 0;
 			table_parent.setLayout(layout);
