@@ -70,7 +70,9 @@ import com.biglybt.ui.swt.progress.ProgressWindow;
 import com.biglybt.ui.swt.search.SearchUI;
 import com.biglybt.ui.swt.shells.CoreWaiterSWT;
 import com.biglybt.ui.swt.shells.MessageBoxShell;
+import com.biglybt.ui.swt.shells.PopOutManager;
 import com.biglybt.ui.swt.shells.main.MainWindowFactory;
+import com.biglybt.ui.swt.shells.opentorrent.OpenTorrentOptionsWindow;
 import com.biglybt.ui.swt.skin.SWTSkin;
 import com.biglybt.ui.swt.skin.SWTSkinPropertiesImpl;
 import com.biglybt.ui.swt.subscriptions.SubscriptionManagerUI;
@@ -316,6 +318,7 @@ public class Initializer
 		FontUtils.dispose();
 		SWTSkinPropertiesImpl.destroyStatics();
 		ProgressWindow.unregister();
+		OpenTorrentOptionsWindow.close();
 	}
 
 	/**
@@ -428,7 +431,7 @@ public class Initializer
 
 			@Override
 			public void stopping(Core core) {
-				Alerts.stopInitiated();
+				handleCoreStopping();
 			}
 
 			@Override
@@ -704,6 +707,11 @@ public class Initializer
 
 			//Tell listeners that all is initialized :
 			Alerts.initComplete();
+			
+			OpenTorrentOptionsWindow.initialise();
+			
+			PopOutManager.initialise();
+			
 		}
 		finally{
 
@@ -713,6 +721,14 @@ public class Initializer
 		}
 	}
 
+	void
+	handleCoreStopping()
+	{
+		Alerts.stopInitiated();
+		
+		OpenTorrentOptionsWindow.close();
+	}
+	
 	@Override
 	public void 
 	stopIt(
@@ -745,7 +761,7 @@ public class Initializer
 							public int 
 							getStyle()
 							{
-								return( STYLE_NO_CLOSE | STYLE_MODAL );
+								return( STYLE_NO_CLOSE | STYLE_MINIMIZE | STYLE_MODAL );
 							}
 							
 							@Override
@@ -758,7 +774,21 @@ public class Initializer
 							public int
 							getSupportedTaskStates()
 							{
-								return( ProgressCallback.ST_SUBTASKS );
+								return( ProgressCallback.ST_SUBTASKS | ProgressCallback.ST_MINIMIZE );
+							}
+							
+							@Override
+							public void 
+							setTaskState(
+								int state )
+							{
+								if ( state == ProgressCallback.ST_MINIMIZE ){
+									
+									UIFunctionsSWT functionsSWT = UIFunctionsManagerSWT.getUIFunctionsSWT();
+									if (functionsSWT != null) {
+										functionsSWT.getMainWindow().setVisible( IMainWindow.WINDOW_ELEMENT_ALL, false );
+									}
+								}
 							}
 						};
 						
