@@ -102,7 +102,7 @@ public class UIConfigDefaultsSWT
 		def.addParameter("Open Bar Incomplete", false);
 		def.addParameter("Open Bar Complete", false);
 
-		def.addParameter("Close To Tray", true);
+		def.addParameter("Close To Tray", Constants.isLinux?false:true);
 		def.addParameter("Minimize To Tray", false);
 
 		def.addParameter("Status Area Show SR", true);
@@ -334,5 +334,7 @@ public class UIConfigDefaultsSWT
 		def.addParameter( ConfigKeys.File.ICFG_UI_ADDTORRENT_OPENOPTIONS_AUTO_CLOSE_SECS, 0 );
 		
 		def.addParameter( "DownloadActivity.show.eta", true );
+		
+		def.addParameter( "blocks.view.max.active", 500 );
 	}
 }
