@@ -76,6 +76,8 @@ public abstract class BaseSwtParameter<PARAMTYPE extends SwtParameter<VALUETYPE>
 
 	private Control mainControl;
 
+	private boolean disposed;
+	
 	public BaseSwtParameter(String paramID) {
 		this.paramID = paramID;
 	}
@@ -212,10 +214,9 @@ public abstract class BaseSwtParameter<PARAMTYPE extends SwtParameter<VALUETYPE>
 				return;
 			}
 			// Note: for Spinner in Windows, getBackground always seems to return white
-			mainControl.setBackground(
-					validationInfo.valid ? null : Colors.colorErrorBG);
-			mainControl.setForeground(
-					validationInfo.valid ? null : Colors.colorError);
+			
+			Utils.setSkinnedForeground(mainControl, validationInfo.valid ? null : Colors.colorError);
+			Utils.setSkinnedBackground(mainControl, validationInfo.valid ? null : Colors.colorErrorBG);
 		});
 	}
 
@@ -660,7 +661,13 @@ public abstract class BaseSwtParameter<PARAMTYPE extends SwtParameter<VALUETYPE>
 		return enabled;
 	}
 
-	public void dispose() {
+	protected void dispose() {
+			// been seeing some crashes in this area, not sure of cause but possible that
+			// we are recursively entering here so prevent that
+		if ( disposed ){
+			return;
+		}
+		disposed = true;
 		validators.clear();
 		change_listeners = null;
 		if (valueProcessor != null) {
@@ -680,6 +687,7 @@ public abstract class BaseSwtParameter<PARAMTYPE extends SwtParameter<VALUETYPE>
 			Link link = new Link(parent, SWT.NONE);
 			label = link;
 			link.addListener(SWT.Selection, event -> Utils.launch(event.text));
+			ClipboardCopy.addCopyToClipMenu(link);
 		} else {
 			label = new Label(parent, SWT.NONE);
 		}
