@@ -140,7 +140,7 @@ public class UIDebugGenerator
 
 				shell.moveAbove( null );
 				
-				Utils.ensureDisplayUpdated( display );
+				Utils.ensureDisplayUpdated();
 
 				if (shell.getData("class") instanceof ObfuscateShell) {
 					ObfuscateShell shellClass = (ObfuscateShell) shell.getData("class");
@@ -574,11 +574,8 @@ public class UIDebugGenerator
 		Utils.centreWindow(shell);
 		shell.open();
 
-		while (!shell.isDisposed()) {
-			if (!shell.getDisplay().readAndDispatch()) {
-				shell.getDisplay().sleep();
-			}
-		}
+		Utils.readAndDispatchLoop( shell );
+
 		if (sendMode[0] != -1) {
 			gr.message = text[0];
 			gr.email = text[1];
