@@ -1198,12 +1198,16 @@ public class ImageLoader
 	 */
 	public Image getUrlImage(String url, final Point maxSize,
 			final ImageDownloaderListener l) {
-		if (!Utils.isThisThreadSWT()) {
-			Debug.out("Called on non-SWT thread");
+		
+		if ( l == null || url == null ){
+			Debug.out( "eh" );
 			return null;
 		}
-		if (l == null || url == null) {
-			return null;
+		
+		if (!Utils.isThisThreadSWT()) {
+			Utils.execSWTThread(()->{ getUrlImage( url, maxSize, l );});
+			
+			return(null);
 		}
 
 		String imageKey = url;
@@ -1391,7 +1395,7 @@ public class ImageLoader
 
 		Rectangle bounds = image.getBounds();
 		if (maxSize.y > 0 && bounds.height > maxSize.y) {
-			int newX = bounds.width * maxSize.y / bounds.height;
+			int newX = Math.max( 1, bounds.width * maxSize.y / bounds.height );
 			if (maxSize.x <= 0 || newX <= maxSize.x) {
 				ImageData scaledTo = image.getImageData().scaledTo(newX, maxSize.y);
 				Device device = image.getDevice();
@@ -1399,7 +1403,7 @@ public class ImageLoader
 			}
 		}
 		if (maxSize.x > 0 && bounds.width > maxSize.x) {
-			int newY = bounds.height * maxSize.x / bounds.width;
+			int newY = Math.max( 1, bounds.height * maxSize.x / bounds.width );
 			ImageData scaledTo = image.getImageData().scaledTo(maxSize.x, newY);
 			Device device = image.getDevice();
 			return new Image(device, scaledTo);
