@@ -1034,7 +1034,7 @@ public class MainStatusBar
 							String url = "feedback.start?" + Utils.getWidgetBGColorURLParam()
 							+ "&fromWeb=false&os.name=" + UrlUtils.encode(Constants.OSName)
 							+ "&os.version="
-							+ UrlUtils.encode(System.getProperty("os.version"))
+							+ UrlUtils.encode(Constants.OSVersion)
 							+ "&java.version=" + UrlUtils.encode(Constants.JAVA_VERSION);
 
 							// Utils.launch( url );
@@ -1046,7 +1046,7 @@ public class MainStatusBar
 
 					Utils.setTT(feedback,MessageText.getString("statusbar.feedback.tooltip"));
 					feedback.setCursor(display.getSystemCursor(SWT.CURSOR_HAND));
-					feedback.setForeground(display.getSystemColor(SWT.COLOR_LINK_FOREGROUND));
+					Utils.setLinkForeground(feedback);
 					feedback.addListener(SWT.MouseUp, feedback_listener);
 					feedback.addListener(SWT.MouseDoubleClick, feedback_listener);
 
@@ -1738,7 +1738,9 @@ public class MainStatusBar
 		// IP Filter Status Section
 		IpFilter ip_filter = core.getIpFilterManager().getIPFilter();
 
-		ipBlocked.setForeground( display.getSystemColor(ip_filter.isEnabled()? SWT.COLOR_WIDGET_FOREGROUND : SWT.COLOR_WIDGET_NORMAL_SHADOW));
+		Color fg = Colors.getSystemColor( ipBlocked.getDisplay(), ip_filter.isEnabled()? SWT.COLOR_WIDGET_FOREGROUND : SWT.COLOR_WIDGET_NORMAL_SHADOW);
+		
+		ipBlocked.setForeground( fg );
 
 		ipBlocked.setText("IPs: "
 				+ numberFormat.format(ip_filter.getNbRanges())
