@@ -22,6 +22,7 @@ import java.io.*;
 import java.net.URL;
 import java.util.*;
 import java.util.List;
+import java.util.function.Supplier;
 
 import com.biglybt.core.Core;
 import com.biglybt.core.CoreFactory;
@@ -91,6 +92,7 @@ import com.biglybt.pif.ui.UIInputReceiver;
 import com.biglybt.pif.ui.UIInputReceiverListener;
 import com.biglybt.pif.ui.menus.MenuManager;
 import com.biglybt.pif.ui.tables.*;
+import com.biglybt.pif.ui.tables.TableColumn;
 import com.biglybt.pif.update.Update;
 import com.biglybt.pif.update.UpdateCheckInstance;
 import com.biglybt.pif.update.UpdateCheckInstanceListener;
@@ -746,6 +748,19 @@ public class MenuFactory
 			}
 		});
 	}
+	
+	public static MenuItem addAllBlocksMenuItem(Menu menu) {
+		return addMenuItem(menu, MENU_ID_ALL_BLOCKS, new Listener() {
+			@Override
+			public void handleEvent(Event e) {
+				UIFunctions uiFunctions = UIFunctionsManager.getUIFunctions();
+				if (uiFunctions != null) {
+					uiFunctions.getMDI().showEntryByID(	MultipleDocumentInterface.SIDEBAR_SECTION_ALLBLOCKS );
+				}
+			}
+		});
+	}
+	
 	public static MenuItem addClientStatsMenuItem(Menu menu) {
 		return addMenuItem(menu, MENU_ID_CLIENT_STATS, new Listener() {
 			@Override
@@ -1284,6 +1299,33 @@ public class MenuFactory
 											});
 								}
 							});
+						
+						MenuItem showThreads = new MenuItem(menu, SWT.PUSH);
+
+						Messages.setLanguageText(showThreads, "show.threads" );
+
+						showThreads.addListener(
+							SWT.Selection,
+							new Listener()
+							{
+								@Override
+								public void
+								handleEvent(
+									Event arg )
+								{
+									Utils.execSWTThreadLater(
+											1,
+											new Runnable()
+											{
+												@Override
+												public void
+												run()
+												{
+													handleShowThreads();
+												}
+											});
+								}
+							});
 					}
 		});
 
@@ -1978,6 +2020,35 @@ public class MenuFactory
 
 	}
 
+	private static void
+	handleShowThreads()
+	{
+		Supplier<String> textGenerator = ()->{
+			
+			StringWriter content = new StringWriter();
+	
+			IndentWriter iw = new IndentWriter( new PrintWriter( content ));
+	
+			AEDiagnostics.dumpThreads( iw );
+			
+			iw.close();
+			
+			return( content.toString());
+		};
+		
+		
+		new TextViewerWindow(
+				null,
+				MessageText.getString( "label.threads" ),
+				null, 
+				textGenerator.get(), 
+				( window )->{
+					window.setText( textGenerator.get(), false );
+				},
+				false, false  );
+
+	}
+	
 	public static MenuItem addBlockedIPsMenuItem(Menu menu) {
 		return addMenuItem(menu, MENU_ID_IP_FILTER, new ListenerNeedingCoreRunning() {
 			@Override
@@ -3086,6 +3157,8 @@ public class MenuFactory
 			  @Override
 			  public TableCell getTableCell(String sColumnName) {notSupported(); return null;}
 			  @Override
+			  public TableCell getTableCell(TableColumn column){ notSupported();return null;}
+			  @Override
 			  public boolean isSelected()  {notSupported(); return false;}
 			  @Override
 			  public void addMouseListener(TableRowMouseListener listener) {notSupported();}
