@@ -59,6 +59,10 @@ public class SWTThread implements AEDiagnosticsEvidenceGenerator {
 
   }
 
+  	// disposal is causing 100% CPU + out of memory on close
+  	// more recently getting crash on exit on Linux ALL THE FEKING TIME
+  
+  boolean skip_dispose = Constants.isLinux ||  Utils.getSWTVersion() >= 4956;
 
   Display display;
   private boolean sleak = false;
@@ -66,9 +70,9 @@ public class SWTThread implements AEDiagnosticsEvidenceGenerator {
   private Thread runner;
   private final IUIIntializer initializer;
 
-	private Monitor primaryMonitor;
-	protected boolean displayDisposed;
-
+  private Monitor primaryMonitor;
+  protected boolean displayDisposed;	
+	
   private
   SWTThread(
   	final IUIIntializer app )
@@ -121,7 +125,7 @@ public class SWTThread implements AEDiagnosticsEvidenceGenerator {
     		Debug.out("Loading SWT Libraries failed. "
     				+ "Typical causes:\n\n"
     				+ "(1) swt.jar is not for your os architecture ("
-    				+ System.getProperty("os.arch") + ").  "
+    				+ Constants.OSArch + ").  "
     				+ "You can get a new swt.jar (Min Version: " + sMin + ") "
     				+ "from http://eclipse.org/swt"
     				+ "\n\n"
@@ -137,7 +141,9 @@ public class SWTThread implements AEDiagnosticsEvidenceGenerator {
     	return;
     }
     
-    Thread.currentThread().setName("SWT Thread");
+    Thread swt_thread = Thread.currentThread();
+
+    swt_thread.setName("SWT Thread");
 
 	Utils.initialize( display );
 
@@ -432,80 +438,187 @@ public class SWTThread implements AEDiagnosticsEvidenceGenerator {
 			}
 	});
 
-    if ( !sleak ){
-      while(display != null && !display.isDisposed() && !terminated) {
-        try {
-            if (display != null && !display.readAndDispatch())
-              display.sleep();
-        }
-        catch (Throwable e) {
-					if (terminated) {
-						Logger.log(new LogEvent(LogIDs.GUI,
-								"Weird non-critical error after terminated in readAndDispatch: "
-										+ e.toString()));
-					} else {
-						String stackTrace = Debug.getStackTrace(e);
-						if (Constants.isOSX
-								&& stackTrace.indexOf("Device.dispose") > 0
-								&& stackTrace.indexOf("DropTarget") > 0) {
-							Logger.log(new LogEvent(LogIDs.GUI,
-									"Weird non-critical display disposal in readAndDispatch"));
-						} else {
-  						// Must use printStackTrace() (no params) in order to get
-  						// "cause of"'s stack trace in SWT < 3119
-  						if (SWT.getVersion() < 3119)
-  							e.printStackTrace();
-  						if (Constants.isCVSVersion()) {
-  							Logger.log(new LogAlert(LogAlert.UNREPEATABLE,MessageText.getString("SWT.alert.erroringuithread"),e));
-  						} else {
-  							Debug.out(MessageText.getString("SWT.alert.erroringuithread"), e);
-  						}
+	if ( !sleak ){
+		
+		
+		SimpleTimer.addPeriodicEvent( 
+			"SWT:ui:check", 1000,
+			new TimerEventPerformer(){
+				
+				Object	lock		= new Object();
+				boolean	active		= false;
+				long	last_exec	= -1;
+				
+				AEDiagnosticsLogger logger;
+				
+				{
+					logger = AEDiagnostics.getLogger( "SlowUI" );
+								
+					logger.setForced( true );
+				}
+				
+				@Override
+				public void 
+				perform(
+					TimerEvent event )
+				{
+					if ( display != null && !display.isDisposed()){
+					
+						long busy_for = -1;
+						
+						synchronized( lock ){
+							
+							if ( active ){
+								
+								busy_for = SystemTime.getMonotonousTime() - last_exec;
+								
+							}else{
+								
+								active = true;
+								
+								last_exec = SystemTime.getMonotonousTime();
+							}
 						}
+						
+						if ( busy_for < 0 ){
+							
+							display.asyncExec(
+								()->{
+									synchronized( lock ){
+										
+										active = false;
+									}
+								});
+						}else{
+								
+							if ( busy_for >= 2000 ){
+								
+								String log = AEDiagnosticsLogger.getTimestamp() + "Busy for " + busy_for + ": " + AEDiagnostics.getThreadInfo( swt_thread );
 
+								StackTraceElement[] elts = swt_thread.getStackTrace();
+								
+								StringBuilder str = new StringBuilder(elts.length * 100);
+	
+								for (int i=0;i<elts.length;i++){
+																	
+									String elt_str = elts[i].toString();
+									
+									if ( elt_str.contains( "SWTThread.<init>" )){
+										
+										break;
+									}
+									
+									str.append("\n\t");
+
+									str.append(elt_str);
+								}
+								
+								logger.log( log + str.toString());
+							}
+						}
 					}
 				}
-      }
+			});
+		
+		while( display != null && !display.isDisposed() && !terminated ){
+			
+			try{
+				if (display != null && !display.readAndDispatch()){
+					
+					display.sleep();
+				}
+			}catch ( Throwable e ){
+				
+				if ( terminated ){
+					
+					Logger.log(new LogEvent(LogIDs.GUI,
+							"Weird non-critical error after terminated in readAndDispatch: "
+									+ e.toString()));
+				}else{
+					
+					String stackTrace = Debug.getStackTrace(e);
+					
+					if (	Constants.isOSX
+							&& stackTrace.indexOf("Device.dispose") > 0
+							&& stackTrace.indexOf("DropTarget") > 0){
+						
+						Logger.log(new LogEvent(LogIDs.GUI,
+								"Weird non-critical display disposal in readAndDispatch"));
+					}else{
+						
+							// Must use printStackTrace() (no params) in order to get
+							// "cause of"'s stack trace in SWT < 3119
+						
+						if (SWT.getVersion() < 3119)
+							e.printStackTrace();
+						if (Constants.isCVSVersion()) {
+							Logger.log(new LogAlert(LogAlert.UNREPEATABLE,MessageText.getString("SWT.alert.erroringuithread"),e));
+						} else {
+							Debug.out(MessageText.getString("SWT.alert.erroringuithread"), e);
+						}
+					}
 
-      if (instance != null) {
-	      if (!terminated) {
+				}
+			}
+		}
 
-		      // if we've falled out of the loop without being explicitly terminated then
-		      // this appears to have been caused by a non-specific exit/restart request (as the
-		      // specific ones should terminate us before disposing of the window...)
-		      if (app != null) {
-			      app.stopIt(false);
-		      }
+		if ( instance != null ){
+			
+			if ( !terminated ){
 
-		      terminate();
-	      }
+					// if we've fallen out of the loop without being explicitly terminated then
+					// this appears to have been caused by a non-specific exit/restart request (as the
+					// specific ones should terminate us before disposing of the window...)
+				
+				if (app != null) {
+					app.stopIt(false);
+				}
 
-	      // dispose platform manager here
-	      PlatformManagerFactory.getPlatformManager().dispose();
-      }
+				terminate();
+			}
+
+			// dispose platform manager here
+			PlatformManagerFactory.getPlatformManager().dispose();
+		}
 
       // Could still be disposing.. wait to be sure
-      try {
-	      while (display != null && !display.isDisposed()) {
-	        if (!display.readAndDispatch() && !display.isDisposed()) {
-	          display.sleep();
+      
+      if ( !skip_dispose ){
+	      try {
+		      while (display != null && !display.isDisposed()) {
+		        if (!display.readAndDispatch() && !display.isDisposed()) {
+		          display.sleep();
+			      }
 		      }
+	      } catch (Exception e) {
+	      	e.printStackTrace();
 	      }
-      } catch (Exception e) {
-      	e.printStackTrace();
       }
     }
   }
 
-  public void terminate() {
-    terminated = true;
-    Utils.setTerminated();
-    // must dispose here in case another window has take over the
+  public void 
+  terminate() 
+  {
+	synchronized( this ){
+		
+		if ( terminated ){
+			
+			return;
+		}
+		
+		terminated = true;
+	}	
+	
+	Utils.setTerminated();
+				
+    // must dispose here in case another window has taken over the
     // readAndDispatch/sleep loop
     
 	// for 1.2 there is a bug https://bugs.eclipse.org/bugs/show_bug.cgi?id=526758 causing crash on exit
 	// apparently fixed in 4.14
 
-    boolean crash_on_dispose_bug = Constants.isWindows8OrHigher && SWT.getVersion() < 4930;
+    boolean crash_on_dispose_bug = Constants.isWindows8OrHigher && SWT.getVersion() < 4930;  
     
     if (!display.isDisposed()) {
     	
@@ -513,6 +626,14 @@ public class SWTThread implements AEDiagnosticsEvidenceGenerator {
     		new Runnable() {
 			    @Override
 			    public void run() {
+			    	
+			    	// while crash is occurring we can just avoid the dispose completely and let the VM death trash things
+
+			    	if ( crash_on_dispose_bug || skip_dispose ){
+			    		
+			    		return;
+			    	}
+			    	
 				    try {
 				    	if ( !display.isDisposed()){
 						    Shell[] shells = display.getShells();
@@ -528,15 +649,11 @@ public class SWTThread implements AEDiagnosticsEvidenceGenerator {
 				    } catch (Throwable t) {
 					    Debug.out(t);
 				    }
-				    
-				    	// while crash is occurring we can just avoid the dispose completely and let the VM death trash things
-				    
-				    if ( !crash_on_dispose_bug ){
-				    	if ( !display.isDisposed()){
-				    		try{
-				    			display.dispose();
-				    		}catch( Throwable e ){
-				    		}
+				    				    				    	
+				    if ( !display.isDisposed()){
+				    	try{
+				    		display.dispose();
+				    	}catch( Throwable e ){
 				    	}
 				    }
 			    }
