@@ -253,9 +253,37 @@ public abstract class BaseMDI
 	                                                   UISWTViewEventListener l, String id, boolean closeable, Object datasource, String preferedAfterID) {
 		// The only thing that uses the method is EMP, which uses a different id based on language
 		
-		UISWTViewBuilderCore builder = new UISWTViewBuilderCore(id,
-				null).setInitialDatasource(datasource).setListenerInstantiator(false,
-			(Builder, view) -> l).setParentEntryID(parentID);
+		UISWTViewBuilderCore builder = 
+			new UISWTViewBuilderCore(
+				id,
+				null).setInitialDatasource(datasource).setListenerInstantiator(
+					new UISWTViewBuilder.UISWTViewEventListenerInstantiator()
+					{
+						@Override
+						public boolean
+						supportsMultipleViews()
+						{
+							return( false );
+						}
+						
+						@Override
+						public UISWTViewEventListener 
+						createNewInstance(
+							UISWTViewBuilder Builder, 
+							UISWTView forView)
+								throws Exception
+						{
+							return( l );
+						}
+						
+						@Override
+						public String 
+						getUID()
+						{
+							return( parentID + "::" + id );
+						}
+					}).setParentEntryID(parentID);
+		
 		return createEntry(builder, closeable);
 	}
 
@@ -546,13 +574,13 @@ public abstract class BaseMDI
 		return loadEntryByID(id, true, false, datasource);
 	}
 	
-	public boolean popoutEntryByID(String id, Object datasource, boolean onTop ) {
+	public boolean popoutEntryByID(String id, Object datasource, Map<String,Object> options ) {
 		
 		MdiEntry existing = getEntry( id, datasource );
 		
 		if ( existing != null ){
 			
-			return( popoutEntry( existing, onTop ));
+			return( popoutEntry( existing, options ));
 		}
 		
 		MdiEntry entry = loadAndGetEntryByID( id, false, false, datasource );
@@ -560,7 +588,7 @@ public abstract class BaseMDI
 		if ( entry != null ){
 				
 			try{
-				return( popoutEntry( entry, onTop ));
+				return( popoutEntry( entry, options ));
 				
 			}finally{
 				
@@ -573,8 +601,8 @@ public abstract class BaseMDI
 	
 	public abstract boolean
 	popoutEntry(
-		MdiEntry	entry,
-		boolean		onTop );
+		MdiEntry			entry,
+		Map<String,Object>	options );
 	
 	@Override
 	public Object skinObjectInitialShow(SWTSkinObject skinObject, Object params) {
@@ -619,7 +647,7 @@ public abstract class BaseMDI
 							// we need to wait for the loadCloseables to complete as there is code in MainMDISetup that runs on the 'UIAttachedComplete'
 							// callback that needs the closables to be loaded (when setting 'start tab') otherwise the order gets broken
 	
-						if ( !wait_sem.reserve(10*1000)){
+						if ( !wait_sem.reserve(20*1000)){
 	
 							Debug.out( "eh?");
 						}
@@ -868,7 +896,17 @@ public abstract class BaseMDI
 					}
 				}
 			}else{
-				initialID = MapUtils.getMapString(loadedMap, CLOSEABLECONFIG_INITIALID, null);
+				String sas = getShowIDAtStartup();
+				
+				if ( sas != null && !sas.isEmpty()){
+					
+					initialID = sas;
+					
+				}else{
+					
+					initialID = MapUtils.getMapString(loadedMap, CLOSEABLECONFIG_INITIALID, null);
+				}
+				
 				if (initialID == null) {
 					String legacyStartTab = COConfigurationManager.getStringParameter("v3.StartTab", null);
 					if (legacyStartTab != null) {
@@ -897,13 +935,26 @@ public abstract class BaseMDI
 				//if (currentEntry != null && !currentEntry.getViewID().equals(initialID)) {
 				//	System.out.println("currentEntry set to " + currentEntry.getViewID() + " before initial " + initialID);
 				//}
-				if (currentEntry == null && initialDef != null) {
-					SimpleTimer.addEvent("ShowDefEntry", SystemTime.getOffsetTime(3000),
-							event -> {
-								if (currentEntry == null) {
-									showEntryByID(initialDef);
+				
+				if ( currentEntry == null ){
+					
+					if ( getEntry( initialID ) != null || initialDef != null ){
+					
+						SimpleTimer.addEvent(
+							"ShowDefEntry", 
+							SystemTime.getOffsetTime(3000),
+							event->{
+								if (currentEntry == null ){
+									
+									if ( getEntry( initialID ) != null ){
+										showEntryByID(initialID);
+									}else if ( initialDef != null ){
+										showEntryByID(initialDef);
+									}
 								}
 							});
+		
+					}
 				}
 			}
 		}catch( Throwable e ){
@@ -916,6 +967,12 @@ public abstract class BaseMDI
 		}
 	}
 
+	protected String
+	getShowIDAtStartup()
+	{
+		return( null );
+	}
+	
 	protected void saveCloseables(){
 		saveCloseables( false );
 	}
@@ -939,14 +996,14 @@ public abstract class BaseMDI
 				return;
 			}
 			
-			try{
-								
+			try{					
+				if ( closed ){
+					
+					return;
+				}
+
 				if ( interim ){
 					
-					if ( closed ){
-						
-						return;
-					}
 				}else{
 					
 					closed = true;
@@ -1004,32 +1061,47 @@ public abstract class BaseMDI
 	private boolean processAutoOpenMap(String id, Map<?, ?> autoOpenInfo,
 			UISWTViewBuilderCore builder) {
 		try {
+
 			MdiEntry entry = getEntry(id);
-			if (entry != null) {
-				return true;
+			
+			if ( entry != null){
+				
+				return( true );
 			}
 
-			String title = MapUtils.getMapString(autoOpenInfo, "title", id);
-
-			MdiEntry mdiEntry = createEntryByCreationListener(id, autoOpenInfo);
-			if (mdiEntry != null) {
-				if (mdiEntry.getTitle().equals("") && !title.isEmpty()) {
-					mdiEntry.setTitle(title);
-				}
-				return true;
-			}
+			String title = MapUtils.getMapString(autoOpenInfo, "title", "" );
 
 			Object datasource = autoOpenInfo.get(AUTOOPENINFO_DS);
 
-			if (builder != null) {
-				entry = createEntry(builder, true);
-				if (entry != null) {
-					if (entry.getTitle().equals("") && !title.isEmpty()) {
-						entry.setTitle(title);
+			entry = createEntryByCreationListener(id, autoOpenInfo);
+			
+			if ( entry != null ){
+				
+				if ( !title.isEmpty()){
+					
+					entry.setTitle(title);
+				}
+			}
+
+
+			if ( entry == null ){
+				
+				if ( builder != null ){
+					
+					entry = createEntry(builder, true);
+					
+					if ( entry != null ){
+						
+						if ( !title.isEmpty()){
+							
+							entry.setTitle( title );
+						}
+						
+							// Auto-Open stores last datasource used before close.
+							// Override builder's initialDataSource with stored one.
+						
+						entry.setDatasource(datasource);
 					}
-					// Auto-Open stores last datasource used before close.
-					// Override builder's initialDataSource with stored one.
-					entry.setDatasource(datasource);
 				}
 			}
 
@@ -1094,7 +1166,8 @@ public abstract class BaseMDI
 
 		setEntryAutoOpen(id, entry.getAutoOpenInfo());
 
-		if (currentEntry == null && id.equals(initialID)) {
+		if ( currentEntry == null && id.equals(initialID)){
+			
 			showEntryByID(initialID);
 		}
 	}
@@ -1239,7 +1312,7 @@ public abstract class BaseMDI
 
 					PluginInterface pi = ((UISWTView) entry).getPluginInterface();
 
-					if (pi != null) {
+					if (pi != null && pi != pi.getPluginManager().getDefaultPluginInterface()){
 
 						final List<String> relevant_sections = new ArrayList<>();
 
