@@ -457,6 +457,9 @@ BasicPluginViewImpl
     if(progress != null) {
       progress.setSelection(model.getProgress().getPercentageComplete());
     }
+    if ( model != null ){
+      model.getLogArea().refresh();
+    }
   }
 
   @Override
