@@ -31,6 +31,8 @@ import org.eclipse.swt.events.DisposeEvent;
 import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.events.PaintEvent;
 import org.eclipse.swt.events.PaintListener;
+import org.eclipse.swt.events.ShellAdapter;
+import org.eclipse.swt.events.ShellEvent;
 import org.eclipse.swt.graphics.*;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -352,6 +354,10 @@ ProgressWindow
 															
 															style |= SWT.APPLICATION_MODAL;
 														}
+														if ((s & ProgressCallback.STYLE_MINIMIZE) != 0 ){
+															
+															style |= SWT.MIN;
+														}
 													}
 												}
 												
@@ -415,12 +421,8 @@ ProgressWindow
 		}.start();
 
 		try{
-			final Display display = Utils.getDisplay();
-
-			while( !( task_complete || display.isDisposed())){
-
-				if (!display.readAndDispatch()) display.sleep();
-			}
+			Utils.readAndDispatchLoop(()->task_complete);
+			
 		}finally{
 
 				// bit of boiler plate in case something fails in the dispatch loop
@@ -509,15 +511,37 @@ ProgressWindow
 			
 			return;
 		}
-		
-		boolean closeable = (shell.getStyle() & SWT.CLOSE ) != 0;
-		
+				
 		shell.setText( MessageText.getString( "progress.window.title" ));
 
 		CoreOperationTask task = _core_op==null?null:_core_op.getTask();
 		
 		ProgressCallback progress = task==null?null:task.getProgressCallback();
 		
+		boolean closeable = (shell.getStyle() & SWT.CLOSE ) != 0;
+
+		if ( progress != null ){
+			
+			int s = progress.getStyle();
+			
+			if ((s & ProgressCallback.STYLE_NO_CLOSE) != 0 ){
+				
+				closeable = false;
+			}
+			
+			if ((s & ProgressCallback.STYLE_MINIMIZE) != 0 ){
+
+				shell.addShellListener( 
+					new ShellAdapter(){
+						@Override
+						public void shellIconified(ShellEvent e){
+							progress.setTaskState(ProgressCallback.ST_MINIMIZE);
+							e.doit = false;
+						}
+					});
+			}
+		}
+		
 		boolean alreadyPositioned = Utils.linkShellMetricsToConfig( shell, "com.biglybt.ui.swt.progress.ProgressWindow" + "." + _core_op.getOperationType());
 		
 		Utils.setShellIcon(shell);
@@ -661,11 +685,12 @@ ProgressWindow
 		
 		if ( progress != null ){
 		
-			Composite compProg = new Composite(shell,SWT.BORDER);
 			gridData = new GridData(GridData.FILL_HORIZONTAL);
 			gridData.grabExcessHorizontalSpace = true;
 			gridData.horizontalSpan = 2;
-			compProg.setLayoutData(gridData);
+			
+			Composite compProg = Utils.createSkinnedComposite(shell,SWT.BORDER,gridData);
+			
 			GridLayout layoutProgress = new GridLayout();
 			layoutProgress.numColumns = 1;
 			layoutProgress.marginWidth = layoutProgress.marginHeight = 0;
@@ -684,7 +709,7 @@ ProgressWindow
 			
 			if ((states & ProgressCallback.ST_BUTTONS) != 0 ){
 				
-				Label labelSeparator = new Label(shell,SWT.SEPARATOR | SWT.HORIZONTAL);
+				Control labelSeparator = Utils.createSkinnedLabelSeparator( shell, SWT.HORIZONTAL);
 				gridData = new GridData(GridData.FILL_HORIZONTAL);
 				gridData.horizontalSpan = 2;
 				labelSeparator.setLayoutData(gridData);
