@@ -138,6 +138,13 @@ SBC_SearchResult
 		return( engine );
 	}
 
+	@Override
+	public String 
+	getID()
+	{
+		return( result.getUID());
+	}
+	
 	@Override
 	public final String
 	getName()
