@@ -226,7 +226,7 @@ public class MainWindowImpl
 					Logger.log(new LogAlert(false, "Error Initialize MainWindow", e));
 				}
 
-				while (!display.isDisposed() && display.readAndDispatch());
+				Utils.readAndDispatchUntilIdle();
 			}
 		});
 	}
@@ -1217,10 +1217,8 @@ public class MainWindowImpl
 			if (display == null) {
 				return;
 			}
-			try {
-  			long endSWTDispatchOn = SystemTime.getOffsetTime(5000);
-				while (SystemTime.getCurrentTime() < endSWTDispatchOn
-  					&& !display.isDisposed() && display.readAndDispatch());
+			try{
+				Utils.readAndDispatchUntilIdleFor( 5000 );
 			} catch (Exception e) {
 				Debug.out(e);
 			}
@@ -1470,7 +1468,7 @@ public class MainWindowImpl
 					}
 				}
 
-				if (!isReady) {
+				if (!isReady && visible) {
 					return;
 				}
 
@@ -1906,7 +1904,7 @@ public class MainWindowImpl
 		}
 		*/
 		
-		final Text text = new Text(cArea, (DARK_MODE && !( Utils.isGTK3 || Constants.isWindows ))?SWT.BORDER:SWT.NONE);
+		final Text text = new Text(cArea, (DARK_MODE && !( Utils.isGTK3 ))?SWT.BORDER:SWT.NONE);
 		text.setMessage(MessageText.getString("v3.MainWindow.search.defaultText"));
 		FormData filledFormData = Utils.getFilledFormData();
 		
@@ -1922,7 +1920,7 @@ public class MainWindowImpl
 		}else if ( Constants.isOSX && DARK_MODE ){
 			filledFormData.height = 19;
 		}else if ( Constants.isWindows && DARK_MODE ){
-			filledFormData.height = 22;
+			filledFormData.height = 20;
 		}
 		
 		text.setLayoutData(filledFormData);
@@ -2144,6 +2142,10 @@ public class MainWindowImpl
 			case WINDOW_ELEMENT_MENU:
 				//TODO:
 				break;
+			case WINDOW_ELEMENT_ALL:{
+
+				return( !shell.getMinimized());
+			}
 		}
 
 		return false;
@@ -2184,6 +2186,15 @@ public class MainWindowImpl
 			case WINDOW_ELEMENT_MENU:
 				//TODO:
 				break;
+			case WINDOW_ELEMENT_ALL:{
+				
+				if ( !shell.isDisposed()){
+					
+					shell.setMinimized( true );
+				}
+				
+				break;
+			}
 		}
 
 	}
