@@ -62,6 +62,7 @@ import com.biglybt.ui.swt.UIFunctionsManagerSWT;
 import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.columns.searchsubs.*;
 import com.biglybt.ui.swt.columns.subscriptions.ColumnSubResultNew;
+import com.biglybt.ui.swt.components.BubbleTextBox;
 import com.biglybt.ui.swt.imageloader.ImageLoader;
 import com.biglybt.ui.swt.mainwindow.ClipboardCopy;
 import com.biglybt.ui.swt.mainwindow.Colors;
@@ -77,6 +78,7 @@ import com.biglybt.ui.swt.views.table.TableViewSWT;
 import com.biglybt.ui.swt.views.table.TableViewSWTMenuFillListener;
 import com.biglybt.ui.swt.views.table.impl.TableViewFactory;
 import com.biglybt.ui.swt.views.table.utils.TableColumnCreator;
+import com.biglybt.ui.swt.views.table.utils.TableColumnFilterHelper;
 import com.biglybt.ui.swt.views.tableitems.ColumnDateSizer;
 
 public class
@@ -94,7 +96,8 @@ SBC_SubscriptionResultsView
 	
 	private static LinkedList<MdiEntrySWT> activated_views	= new LinkedList<>();
 	
-	private TableViewSWT<SubscriptionResultFilterable> tv_subs_results;
+	private TableViewSWT<SubscriptionResultFilterable>				tv_subs_results;
+	private TableColumnFilterHelper<SubscriptionResultFilterable>	col_filter_helper;
 
 	private MdiEntrySWT			mdi_entry;
 	private Composite			table_parent;
@@ -257,7 +260,6 @@ SBC_SubscriptionResultsView
 
 			Composite parent = (Composite) soFilterArea.getControl();
 
-			Label label;
 			FormData fd;
 			GridLayout layout;
 			int sepHeight = 20;
@@ -344,23 +346,38 @@ SBC_SubscriptionResultsView
 								long kInB = DisplayFormatters.getKinB();
 								long mInB = kInB*kInB;
 	
+								String mb = DisplayFormatters.getUnit( DisplayFormatters.UNIT_MB );
+								
+								String with_words = getString( ds_filter.getWithWords());
+								String without_words = getString( ds_filter.getWithoutWords());
+								
 								long	min_size = Math.max( 0,  ds_filter.getMinSize()/mInB );
 								long	max_size = Math.max( 0,  ds_filter.getMaxSize()/mInB );
 								long	min_seeds = Math.max( 0,  ds_filter.getMinSeeds());
+								long	max_seeds = Math.max( 0,  ds_filter.getMaxSeeds());
+								long	min_peers = Math.max( 0,  ds_filter.getMinPeers());
 								long	max_age = Math.max( 0,  ds_filter.getMaxAgeSecs());
 								
-								pflabel.setText(
-									MessageText.getString(
-										"subs.persistent.filters",
-										new String[]{
-											getString( ds_filter.getWithWords()),
-											getString( ds_filter.getWithoutWords()),
-											String.valueOf( min_size ),
-											String.valueOf( max_size )
-										
-										}) +
-									", " + MessageText.getString( "label.min.seeds") + " = " + ( min_seeds ) + 
-									", " + MessageText.getString( "label.max.age") + " = " + (TimeFormatter.format3( max_age, null, true )));
+								String[] line = {""};
+								
+								addLine( line, !with_words.isEmpty(), MessageText.getString( "SubscriptionResults.filter.with.words" ), "[" + with_words + "]" );	
+								addLine( line, !without_words.isEmpty(), MessageText.getString( "SubscriptionResults.filter.without.words" ), "[" + without_words + "]" );	
+								addLine( line, min_size>0, MessageText.getString( "label.min.size"),  min_size + " " + mb ); 
+								addLine( line, max_size>0, MessageText.getString( "label.max.size"),  max_size + " " + mb); 
+								addLine( line, min_seeds>0, MessageText.getString( "label.min.seeds"), String.valueOf( min_seeds ));
+								addLine( line, max_seeds>0, MessageText.getString( "label.max.seeds"), String.valueOf(max_seeds )); 
+								addLine( line, min_peers>0, MessageText.getString( "label.min.peers"), String.valueOf(min_peers )); 
+								addLine( line, max_age>0, MessageText.getString( "label.max.age"), TimeFormatter.format3( max_age, null, true ));
+								
+								String pf = line[0].trim();
+								
+								if ( pf.isEmpty()){
+									
+									pf = MessageText.getString( "label.none" );
+								}
+								
+								pflabel.setText( MessageText.getString("subs.persistent.filters2" ) + ": " + pf );
+								
 							}else{
 								pflabel.setVisible( false );
 								GridData gd = (GridData)pflabel.getLayoutData();
@@ -380,9 +397,8 @@ SBC_SubscriptionResultsView
 			Composite vFilters = new Composite(cFilters, SWT.NONE);
 			vFilters.setLayoutData(new GridData( GridData.FILL_HORIZONTAL ));
 
-
 			RowLayout rowLayout = new RowLayout(SWT.HORIZONTAL);
-			rowLayout.spacing = 5;
+			rowLayout.spacing = 3;
 			rowLayout.marginBottom = rowLayout.marginTop = rowLayout.marginLeft = rowLayout.marginRight = 0;
 			rowLayout.center = true;
 			vFilters.setLayout(rowLayout);
@@ -409,8 +425,8 @@ SBC_SubscriptionResultsView
 
 				if ( !with ){
 
-					label = new Label(vFilters, SWT.VERTICAL | SWT.SEPARATOR);
-					label.setLayoutData(new RowData(-1, sepHeight));
+					Control sep = Utils.createSkinnedLabelSeparator(vFilters, SWT.VERTICAL );
+					sep.setLayoutData(new RowData(-1, sepHeight));
 				}
 
 				Composite cWithKW = new Composite(vFilters, SWT.NONE);
@@ -465,128 +481,206 @@ SBC_SubscriptionResultsView
 			
 				// min size
 
-			label = new Label(vFilters, SWT.VERTICAL | SWT.SEPARATOR);
-			label.setLayoutData(new RowData(-1, sepHeight));
+			Control sep = Utils.createSkinnedLabelSeparator(vFilters, SWT.VERTICAL );
+			sep.setLayoutData(new RowData(-1, sepHeight));
 
-			Composite cMinSize = new Composite(vFilters, SWT.NONE);
-			layout = new GridLayout(2, false);
-			layout.marginWidth = 0;
-			layout.marginBottom = layout.marginTop = layout.marginLeft = layout.marginRight = 0;
-			cMinSize.setLayout(layout);
-			Label lblMinSize = new Label(cMinSize, SWT.NONE);
-			lblMinSize.setText(MessageText.getString("SubscriptionResults.filter.min_size"));
-			Spinner spinMinSize = new Spinner(cMinSize, SWT.BORDER);
-			spinMinSize.setMinimum(0);
-			spinMinSize.setMaximum(100*kInB*kInB);	// 100 TB should do...
-			spinMinSize.setSelection(Math.max( 0,  (int)( ds_filter.getMinSize()/mInB )));
-			spinMinSize.addListener(SWT.Selection, new Listener() {
-				@Override
-				public void handleEvent(Event event) {
-					ds_filter.setMinSize(((Spinner) event.widget).getSelection() * mInB);
-					refilter_dispatcher.dispatch();
-				}
-			});
-
-			// max size
-
-			label = new Label(vFilters, SWT.VERTICAL | SWT.SEPARATOR);
-			label.setLayoutData(new RowData(-1, sepHeight));
-
-			Composite cMaxSize = new Composite(vFilters, SWT.NONE);
-			layout = new GridLayout(2, false);
-			layout.marginWidth = 0;
-			layout.marginBottom = layout.marginTop = layout.marginLeft = layout.marginRight = 0;
-			cMaxSize.setLayout(layout);
-			Label lblMaxSize = new Label(cMaxSize, SWT.NONE);
-			lblMaxSize.setText(MessageText.getString("SubscriptionResults.filter.max_size"));
-			Spinner spinMaxSize = new Spinner(cMaxSize, SWT.BORDER);
-			spinMaxSize.setMinimum(0);
-			spinMaxSize.setMaximum(100*kInB*kInB);	// 100 TB should do...
-			spinMaxSize.setSelection(Math.max( 0,  (int)( ds_filter.getMaxSize()/mInB )));
-			spinMaxSize.addListener(SWT.Selection, new Listener() {
-				@Override
-				public void handleEvent(Event event) {
-					ds_filter.setMaxSize(((Spinner) event.widget).getSelection() * mInB);
-					refilter_dispatcher.dispatch();
-				}
-			});
-
-				// min seeds
-			
-			label = new Label(vFilters, SWT.VERTICAL | SWT.SEPARATOR);
-			label.setLayoutData(new RowData(-1, sepHeight));
-
-			Composite cMinSeeds = new Composite(vFilters, SWT.NONE);
-			layout = new GridLayout(2, false);
-			layout.marginWidth = 0;
-			layout.marginBottom = layout.marginTop = layout.marginLeft = layout.marginRight = 0;
-			cMinSeeds.setLayout(layout);
-			Label lblMinSeeds = new Label(cMinSeeds, SWT.NONE);
-			lblMinSeeds.setText(MessageText.getString("label.min.seeds"));
-			Spinner spinMinSeeds = new Spinner(cMinSeeds, SWT.BORDER);
-			spinMinSeeds.setMinimum(0);
-			spinMinSeeds.setMaximum(Integer.MAX_VALUE);
-			spinMinSeeds.setSelection((int)ds_filter.getMinSeeds());
-			spinMinSeeds.addListener(SWT.Selection, new Listener() {
-				@Override
-				public void handleEvent(Event event) {
-					ds_filter.setMinSeeds(((Spinner) event.widget).getSelection());
-					refilter_dispatcher.dispatch();
-				}
-			});
-
-			
-				// max age
-			
-			label = new Label(vFilters, SWT.VERTICAL | SWT.SEPARATOR);
-			label.setLayoutData(new RowData(-1, sepHeight));
-
-			Composite cMaxAge = new Composite(vFilters, SWT.NONE);
-			layout = new GridLayout(3, false);
-			layout.marginWidth = 0;
-			layout.marginBottom = layout.marginTop = layout.marginLeft = layout.marginRight = 0;
-			cMaxAge.setLayout(layout);
-			
-			Label lblMaxAge = new Label(cMaxAge, SWT.NONE);
-			lblMaxAge.setText(MessageText.getString("label.max.age"));
-			
-			Spinner spinMaxAge = new Spinner(cMaxAge, SWT.BORDER);
-			spinMaxAge.setMinimum(0);
-			spinMaxAge.setMaximum(Integer.MAX_VALUE);
-			
-			Combo combMaxAge = new Combo( cMaxAge, SWT.SINGLE | SWT.READ_ONLY );
-			
-			for ( String unit: TimeFormatter.TIME_SUFFIXES_2 ){
-			
-				combMaxAge.add( unit );
+			{
+				Composite cMinSize = new Composite(vFilters, SWT.NONE);
+				layout = new GridLayout(2, false);
+				layout.marginWidth = 0;
+				layout.marginBottom = layout.marginTop = layout.marginLeft = layout.marginRight = 0;
+				cMinSize.setLayout(layout);
+				Label lblMinSize = new Label(cMinSize, SWT.NONE);
+				lblMinSize.setText(MessageText.getString("label.min.size") + " (" + DisplayFormatters.getUnit(DisplayFormatters.UNIT_MB) + ")");
+				Spinner spinMinSize = new Spinner(cMinSize, SWT.BORDER);
+				GridData gd = new GridData();
+				gd.widthHint = 20;
+				spinMinSize.setLayoutData(gd);
+				spinMinSize.setMinimum(0);
+				spinMinSize.setMaximum(100*kInB*kInB);	// 100 TB should do...
+				spinMinSize.setSelection(Math.max( 0,  (int)( ds_filter.getMinSize()/mInB )));
+				spinMinSize.addListener(SWT.Selection, new Listener() {
+					@Override
+					public void handleEvent(Event event) {
+						ds_filter.setMinSize(((Spinner) event.widget).getSelection() * mInB);
+						refilter_dispatcher.dispatch();
+					}
+				});
 			}
 			
-			Listener maxAgeListener = (e)->{
-				int	val 	= spinMaxAge.getSelection();
-				int unit	= combMaxAge.getSelectionIndex();
+			// max size
+
+			sep = Utils.createSkinnedLabelSeparator(vFilters, SWT.VERTICAL );
+			sep.setLayoutData(new RowData(-1, sepHeight));
+
+			{
+				Composite cMaxSize = new Composite(vFilters, SWT.NONE);
+				layout = new GridLayout(2, false);
+				layout.marginWidth = 0;
+				layout.marginBottom = layout.marginTop = layout.marginLeft = layout.marginRight = 0;
+				cMaxSize.setLayout(layout);
+				Label lblMaxSize = new Label(cMaxSize, SWT.NONE);
+				lblMaxSize.setText(MessageText.getString("label.max.size") + " (" + DisplayFormatters.getUnit(DisplayFormatters.UNIT_MB) + ")");
+				Spinner spinMaxSize = new Spinner(cMaxSize, SWT.BORDER);
+				GridData gd = new GridData();
+				gd.widthHint = 20;
+				spinMaxSize.setLayoutData(gd);
+				spinMaxSize.setMinimum(0);
+				spinMaxSize.setMaximum(100*kInB*kInB);	// 100 TB should do...
+				spinMaxSize.setSelection(Math.max( 0,  (int)( ds_filter.getMaxSize()/mInB )));
+				spinMaxSize.addListener(SWT.Selection, new Listener() {
+					@Override
+					public void handleEvent(Event event) {
+						ds_filter.setMaxSize(((Spinner) event.widget).getSelection() * mInB);
+						refilter_dispatcher.dispatch();
+					}
+				});
+			}
+			
+				// min seeds
+			
+			sep = Utils.createSkinnedLabelSeparator(vFilters, SWT.VERTICAL );
+			sep.setLayoutData(new RowData(-1, sepHeight));
+
+			{	
+				Composite cMinSeeds = new Composite(vFilters, SWT.NONE);
+				layout = new GridLayout(2, false);
+				layout.marginWidth = 0;
+				layout.marginBottom = layout.marginTop = layout.marginLeft = layout.marginRight = 0;
+				cMinSeeds.setLayout(layout);
+				Label lblMinSeeds = new Label(cMinSeeds, SWT.NONE);
+				lblMinSeeds.setText(MessageText.getString("label.min.seeds"));
+				Spinner spinMinSeeds = new Spinner(cMinSeeds, SWT.BORDER);
+				GridData gd = new GridData();
+				gd.widthHint = 20;
+				spinMinSeeds.setLayoutData(gd);
+				spinMinSeeds.setMinimum(0);
+				spinMinSeeds.setMaximum(Integer.MAX_VALUE);
+				spinMinSeeds.setSelection((int)ds_filter.getMinSeeds());
+				spinMinSeeds.addListener(SWT.Selection, new Listener() {
+					@Override
+					public void handleEvent(Event event) {
+						ds_filter.setMinSeeds(((Spinner) event.widget).getSelection());
+						refilter_dispatcher.dispatch();
+					}
+				});
+			}
+			
+				// max seeds
+			
+			sep = Utils.createSkinnedLabelSeparator(vFilters, SWT.VERTICAL );
+			sep.setLayoutData(new RowData(-1, sepHeight));
+
+			{		
+				Composite cMaxSeeds = new Composite(vFilters, SWT.NONE);
+				layout = new GridLayout(2, false);
+				layout.marginWidth = 0;
+				layout.marginBottom = layout.marginTop = layout.marginLeft = layout.marginRight = 0;
+				cMaxSeeds.setLayout(layout);
+				Label lblMaxSeeds = new Label(cMaxSeeds, SWT.NONE);
+				lblMaxSeeds.setText(MessageText.getString("label.max.seeds"));
+				Spinner spinMaxSeeds = new Spinner(cMaxSeeds, SWT.BORDER);
+				GridData gd = new GridData();
+				gd.widthHint = 20;
+				spinMaxSeeds.setLayoutData(gd);
+				spinMaxSeeds.setMinimum(0);
+				spinMaxSeeds.setMaximum(Integer.MAX_VALUE);
+				spinMaxSeeds.setSelection((int)ds_filter.getMaxSeeds());
+				spinMaxSeeds.addListener(SWT.Selection, new Listener() {
+					@Override
+					public void handleEvent(Event event) {
+						ds_filter.setMaxSeeds(((Spinner) event.widget).getSelection());
+						refilter_dispatcher.dispatch();
+					}
+				});
+			}
+			
+				// min peers
+			
+			sep = Utils.createSkinnedLabelSeparator(vFilters, SWT.VERTICAL );
+			sep.setLayoutData(new RowData(-1, sepHeight));
+
+			{
+	
+				Composite cMinPeers = new Composite(vFilters, SWT.NONE);
+				layout = new GridLayout(2, false);
+				layout.marginWidth = 0;
+				layout.marginBottom = layout.marginTop = layout.marginLeft = layout.marginRight = 0;
+				cMinPeers.setLayout(layout);
+				Label lblMinPeers = new Label(cMinPeers, SWT.NONE);
+				lblMinPeers.setText(MessageText.getString("label.min.peers"));
+				Spinner spinMinPeers = new Spinner(cMinPeers, SWT.BORDER);
+				GridData gd = new GridData();
+				gd.widthHint = 20;
+				spinMinPeers.setLayoutData(gd);
+				spinMinPeers.setMinimum(0);
+				spinMinPeers.setMaximum(Integer.MAX_VALUE);
+				spinMinPeers.setSelection((int)ds_filter.getMinPeers());
+				spinMinPeers.addListener(SWT.Selection, new Listener() {
+					@Override
+					public void handleEvent(Event event) {
+						ds_filter.setMinPeers(((Spinner) event.widget).getSelection());
+						refilter_dispatcher.dispatch();
+					}
+				});
+			}
+					
+				// max age
+			
+			sep = Utils.createSkinnedLabelSeparator(vFilters, SWT.VERTICAL );
+			sep.setLayoutData(new RowData(-1, sepHeight));
+
+			{
+				Composite cMaxAge = new Composite(vFilters, SWT.NONE);
+				layout = new GridLayout(3, false);
+				layout.marginWidth = 0;
+				layout.marginBottom = layout.marginTop = layout.marginLeft = layout.marginRight = 0;
+				cMaxAge.setLayout(layout);
 				
-				long secs = TimeFormatter.TIME_SUFFIXES_2_MULT[unit] * (long)( val + 1 ) - 1;
+				Label lblMaxAge = new Label(cMaxAge, SWT.NONE);
+				lblMaxAge.setText(MessageText.getString("label.max.age"));
 				
-				ds_filter.setMaxAgeSecs( secs );
+				Spinner spinMaxAge = new Spinner(cMaxAge, SWT.BORDER);
+				GridData gd = new GridData();
+				gd.widthHint = 20;
+				spinMaxAge.setLayoutData(gd);
+				spinMaxAge.setMinimum(0);
+				spinMaxAge.setMaximum(Integer.MAX_VALUE);
 				
-				refilter_dispatcher.dispatch();
-			};
-			
-			int[] temp = TimeFormatter.format3Support( ds_filter.getMaxAgeSecs(), null, true );
-			
-			int val = temp[0];
-			
-			spinMaxAge.setSelection( val<0?0:val );
-			combMaxAge.select( temp[1] );			
-			
-			spinMaxAge.addListener(SWT.Selection, maxAgeListener );		
-			combMaxAge.addListener(SWT.Selection, maxAgeListener );
+				Combo combMaxAge = new Combo( cMaxAge, SWT.SINGLE | SWT.READ_ONLY );
+				
+				for ( String unit: TimeFormatter.TIME_SUFFIXES_2 ){
+				
+					combMaxAge.add( unit );
+				}
+				
+				Listener maxAgeListener = (e)->{
+					int	val 	= spinMaxAge.getSelection();
+					int unit	= combMaxAge.getSelectionIndex();
+					
+					long secs = TimeFormatter.TIME_SUFFIXES_2_MULT[unit] * (long)( val + 1 ) - 1;
+					
+					ds_filter.setMaxAgeSecs( secs );
+					
+					refilter_dispatcher.dispatch();
+				};
+				
+				int[] temp = TimeFormatter.format3Support( ds_filter.getMaxAgeSecs(), null, true );
+				
+				int val = temp[0];
+				
+				spinMaxAge.setSelection( val<0?0:val );
+				combMaxAge.select( temp[1] );			
+				
+				spinMaxAge.addListener(SWT.Selection, maxAgeListener );		
+				combMaxAge.addListener(SWT.Selection, maxAgeListener );
+			}
 			
 			if ( ds != null ){
 
 				if ( ds.isUpdateable() ){
-					label = new Label(vFilters, SWT.VERTICAL | SWT.SEPARATOR);
-					label.setLayoutData(new RowData(-1, sepHeight));
+					sep = Utils.createSkinnedLabelSeparator(vFilters, SWT.VERTICAL );
+					sep.setLayoutData(new RowData(-1, sepHeight));
 	
 					final Runnable					f_pFilterUpdater 	= pFilterUpdater;
 	
@@ -609,8 +703,8 @@ SBC_SubscriptionResultsView
 					});
 				}
 				
-				label = new Label(vFilters, SWT.VERTICAL | SWT.SEPARATOR);
-				label.setLayoutData(new RowData(-1, sepHeight));
+				sep = Utils.createSkinnedLabelSeparator(vFilters, SWT.VERTICAL );
+				sep.setLayoutData(new RowData(-1, sepHeight));
 				
 				Button more = new Button( vFilters,SWT.PUSH );
 				more.setText( MessageText.getString( "Subscription.menu.forcecheck" ));
@@ -673,6 +767,27 @@ SBC_SubscriptionResultsView
 		return null;
 	}
 
+	private void
+	addLine(
+		String[]	line,
+		boolean		add,
+		String		name,
+		String		value )
+	{
+		if ( add ){
+			
+			String text = name + " = " + value;
+			
+			if ( line[0].isEmpty()){
+				
+				line[0] = text;
+				
+			}else{
+				
+				line[0] += ", " + text;
+			}
+		}
+	}
 	private String
 	getString(
 		String[]	strs )
@@ -895,6 +1010,66 @@ SBC_SubscriptionResultsView
 						new ColumnSearchSubResultExisting(column);
 					}
 				});
+		
+		tableManager.registerColumn(
+				SubscriptionResultFilterable.class,
+				ColumnSearchSubResultDLHistoryAdded.COLUMN_ID,
+				new TableColumnCoreCreationListener() {
+					@Override
+					public TableColumnCore 
+					createTableColumnCore(
+							Class<?> forDataSourceType, String tableID, String columnID) 
+					{
+						return new ColumnDateSizer(
+								SubscriptionResultFilterable.class, columnID,
+								TableColumnCreator.DATE_COLUMN_WIDTH, tableID){};
+					}
+
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnSearchSubResultDLHistoryAdded(column);
+					}
+				});
+		
+		tableManager.registerColumn(
+			SubscriptionResultFilterable.class,
+			ColumnSearchSubResultDLHistoryCompleted.COLUMN_ID,
+			new TableColumnCoreCreationListener() {
+				@Override
+				public TableColumnCore 
+				createTableColumnCore(
+						Class<?> forDataSourceType, String tableID, String columnID) 
+				{
+					return new ColumnDateSizer(
+							SubscriptionResultFilterable.class, columnID,
+							TableColumnCreator.DATE_COLUMN_WIDTH, tableID){};
+				}
+
+				@Override
+				public void tableColumnCreated(TableColumn column) {
+					new ColumnSearchSubResultDLHistoryCompleted(column);
+				}
+			});
+		
+		tableManager.registerColumn(
+				SubscriptionResultFilterable.class,
+				ColumnSearchSubResultDLHistoryRemoved.COLUMN_ID,
+				new TableColumnCoreCreationListener() {
+					@Override
+					public TableColumnCore 
+					createTableColumnCore(
+							Class<?> forDataSourceType, String tableID, String columnID) 
+					{
+						return new ColumnDateSizer(
+								SubscriptionResultFilterable.class, columnID,
+								TableColumnCreator.DATE_COLUMN_WIDTH, tableID){};
+					}
+
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnSearchSubResultDLHistoryRemoved(column);
+					}
+				});
 	}
 
 	@Override
@@ -1191,7 +1366,15 @@ SBC_SubscriptionResultsView
 
 		SWTSkinObjectTextbox soFilterBox = (SWTSkinObjectTextbox) getSkinObject("filterbox");
 		if (soFilterBox != null) {
-			tv_subs_results.enableFilterCheck(soFilterBox.getBubbleTextBox(), this);
+			BubbleTextBox bubbleTextBox = soFilterBox.getBubbleTextBox();
+			
+			tv_subs_results.enableFilterCheck(bubbleTextBox, this);
+			
+			String tooltip = MessageText.getString("filter.tt.start");
+			tooltip += MessageText.getString("column.filter.tt.line1");
+			tooltip += MessageText.getString("column.filter.tt.line2");
+
+			bubbleTextBox.setTooltip( tooltip );
 		}
 
 		tv_subs_results.setRowDefaultHeight(COConfigurationManager.getIntParameter( "Search Subs Row Height" ));
@@ -1461,6 +1644,8 @@ SBC_SubscriptionResultsView
 		}
 		*/
 
+		col_filter_helper = new TableColumnFilterHelper<>( tv_subs_results, "srv:search" );
+		
 		tv_subs_results.initialize( table_parent );
 
 		control.layout(true);
@@ -1572,7 +1757,7 @@ SBC_SubscriptionResultsView
 			return false;
 		}
 
-		return( SearchSubsUtils.filterCheck( ds, filter, regex, confusable ));
+		return( SearchSubsUtils.filterCheck( col_filter_helper, ds, filter, regex, confusable ));
 	}
 
 	@Override
