@@ -451,22 +451,23 @@ SubscriptionManagerUI
 			@Override
 			public void
 			subscriptionAdded(
-					Subscription 		subscription )
+				Subscription 		subscription )
 			{
 			}
 
 			@Override
 			public void
 			subscriptionChanged(
-					Subscription		sub )
+				Subscription		sub,
+				int					reason )
 			{
-				changeSubscription( sub );
+				changeSubscription( sub, reason );
 			}
 
 			@Override
 			public void
 			subscriptionSelected(
-					Subscription sub )
+				Subscription sub )
 			{
 				showSubscriptionMDI( sub );
 			}
@@ -474,7 +475,7 @@ SubscriptionManagerUI
 			@Override
 			public void
 			subscriptionRemoved(
-					Subscription 		subscription )
+				Subscription 		subscription )
 			{
 				removeSubscription( subscription );
 			}
@@ -482,15 +483,15 @@ SubscriptionManagerUI
 			@Override
 			public void
 			associationsChanged(
-					byte[]		association_hash )
+				byte[]		association_hash )
 			{
 			}
 
 			@Override
 			public void
 			subscriptionRequested(
-					URL					url,
-					Map<String,Object>	options )
+				URL					url,
+				Map<String,Object>	options )
 			{
 			}
 		};
@@ -522,13 +523,13 @@ SubscriptionManagerUI
 		try {
 			TableManager tableManager = PluginInitializer.getDefaultInterface().getUIManager().getTableManager();
 			if (columnCreationSubs != null) {
-				tableManager.unregisterColumn(Download.class, "azsubs.ui.column.subs",
-						columnCreationSubs);
+				tableManager.unregisterColumn(Download.class, "azsubs.ui.column.subs" );
+						
 				columnCreationSubs = null;
 			}
 			if (columnCreationSubsLink != null) {
-				tableManager.unregisterColumn(Download.class, "azsubs.ui.column.subs_link",
-						columnCreationSubsLink);
+				tableManager.unregisterColumn(Download.class, "azsubs.ui.column.subs_link" );
+						
 				columnCreationSubsLink = null;
 			}
 		} catch (Throwable ignore) {
@@ -559,7 +560,7 @@ SubscriptionManagerUI
 			@Override
 			public void
 			subscriptionAdded(
-					Subscription subscription )
+				Subscription subscription )
 			{
 				checkSubscriptionForStuff( subscription );
 			}
@@ -567,28 +568,30 @@ SubscriptionManagerUI
 			@Override
 			public void
 			subscriptionChanged(
-					Subscription		subscription )
+				Subscription		subscription,
+				int					reason )
 			{
+				changeSubscription(subscription, reason);
 			}
 
 			@Override
 			public void
 			subscriptionSelected(
-					Subscription subscription )
+				Subscription subscription )
 			{
 			}
 
 			@Override
 			public void
 			subscriptionRemoved(
-					Subscription subscription )
+				Subscription subscription )
 			{
 			}
 
 			@Override
 			public void
 			associationsChanged(
-					byte[] hash )
+				byte[] hash )
 			{
 				refreshColumns();
 			}
@@ -596,8 +599,8 @@ SubscriptionManagerUI
 			@Override
 			public void
 			subscriptionRequested(
-					final URL					url,
-					final Map<String,Object>	options )
+				final URL					url,
+				final Map<String,Object>	options )
 			{
 				Utils.execSWTThread(
 						new AERunnable()
@@ -898,6 +901,25 @@ SubscriptionManagerUI
 				}
 			});
 
+			// mark results in library read
+	
+		final BooleanParameter mark_lib_results_read =
+			configModel.addBooleanParameter2(
+				"subscriptions.mark_results_in_lib.enable", "subscriptions.mark_results_in_lib.enable",
+				subs_man.getMarkResultsInLibraryRead());
+	
+		mark_lib_results_read.addListener(
+			new ParameterListener()
+			{
+				@Override
+				public void
+				parameterChanged(
+					Parameter param)
+				{
+					subs_man.setMarkResultsInLibraryRead( mark_lib_results_read.getValue());
+				}
+			});		
+		
 		final IntParameter def_check =
 				configModel.addIntParameter2(
 					"subscriptions.config.def.check",
@@ -1181,8 +1203,6 @@ SubscriptionManagerUI
 
 								new SubscriptionWizard(PluginCoreUtils.unwrap(dl));
 
-								COConfigurationManager.setParameter( "subscriptions.wizard.shown", true );
-
 								refreshTitles( mdiEntryOverview );
 
 								//new SubscriptionListWindow(PluginCoreUtils.unwrap(dl),true);
@@ -1405,6 +1425,31 @@ SubscriptionManagerUI
 				}
 			});
 
+		mi = menu_manager.addMenuItem( parentID, "Subscription.menu.clearall" );
+		mi.setDisposeWithUIDetach(UIInstance.UIT_SWT);
+
+		mi.addListener(
+			new MenuItemListener()
+			{
+				@Override
+				public void
+				selected(
+					MenuItem menu, Object target )
+				{
+					SubscriptionManager subs_man = SubscriptionManagerFactory.getSingleton();
+
+					Subscription[] subs = subs_man.getSubscriptions( true );
+
+					for ( Subscription sub: subs ){
+
+						if ( !sub.isSearchTemplate()){
+
+							sub.getHistory().markAllResultsRead();
+						}
+					}
+				}
+			});
+		
 		mi = menu_manager.addMenuItem( parentID, "sep1" );
 		mi.setDisposeWithUIDetach(UIInstance.UIT_SWT);
 
@@ -1446,8 +1491,6 @@ SubscriptionManagerUI
 				public void mdiEntryVitalityImage_clicked(int x, int y) {
 					new SubscriptionWizard();
 
-					COConfigurationManager.setParameter( "subscriptions.wizard.shown", true );
-
 					refreshTitles( mdiEntryOverview );
 				}
 			});
@@ -1477,8 +1520,6 @@ SubscriptionManagerUI
 				{
 					Object result = null;
 
-					// COConfigurationManager.setParameter( "subscriptions.wizard.shown", false );
-
 					if (propertyID == TITLE_INDICATOR_TEXT) {
 
 						//boolean expanded = headerEntry.isExpanded();
@@ -1586,7 +1627,8 @@ SubscriptionManagerUI
 
 	protected void
 	changeSubscription(
-		final Subscription	subs )
+		final Subscription	subs,
+		int					reason )
 	{
 		refreshTitles( mdiEntryOverview );
 
@@ -1892,6 +1934,7 @@ SubscriptionManagerUI
 
 		while( entry != null ){
 
+			entry.redraw();
 			ViewTitleInfoManager.refreshTitleInfo(entry.getViewTitleInfo());
 
 			String key = entry.getParentID();
@@ -1959,42 +2002,146 @@ SubscriptionManagerUI
 	{
 		if ( all_subs.length > 1 ){
 
-			MenuItem menuItem = menu_creator.createMenu( "menu.set.parent");
+			boolean all_search_templates = true;
+			
+			for ( Subscription sub: all_subs ){
+			
+				if ( !sub.isSearchTemplate()){
+					
+					all_search_templates = false;
+					
+					break;
+				}
+			}
+			
+			if ( !all_search_templates ){
+				
+				MenuItem menuItem = menu_creator.createMenu( "Subscription.menu.forcecheck" );
+				menuItem.setText(MessageText.getString("Subscription.menu.forcecheck"));
+				menuItem.addMultiListener(new SubsMenuItemListener() {
+					@Override
+					public void selected(Subscription[] subs) {
+						for ( Subscription sub: subs ){
+							if ( sub.isSearchTemplate()){
+								continue;
+							}
+							try {
+								sub.getManager().getScheduler().downloadAsync( sub, true );
+							} catch (SubscriptionException e) {
+								Debug.out(e);
+							}
+						}
+					}
+				});
+	
+				menuItem = menu_creator.createMenu( "Subscription.menu.clearall");
+				menuItem.addMultiListener(new SubsMenuItemListener() {
+					@Override
+					public void selected(Subscription[] subs) {
+						for ( Subscription sub: subs ){
+							if ( sub.isSearchTemplate()){
+								continue;
+							}
+							sub.getHistory().markAllResultsRead();
+						}
+						menu_creator.refreshView();
+					}
+				});
+				
+				menu_creator.createMenu( "s1").setStyle( MenuItem.STYLE_SEPARATOR );
 
+				menuItem = menu_creator.createMenu( "menu.set.parent");
+	
+				menuItem.addMultiListener(new SubsMenuItemListener() {
+					@Override
+					public void selected(final Subscription[] subs) {
+						UISWTInputReceiver entry = new SimpleTextEntryWindow();
+						if ( subs.length==1 ){
+							entry.setPreenteredText(subs[0].getParent(), false );
+						}
+						entry.maintainWhitespace(false);
+						entry.allowEmptyInput( true );
+						entry.setLocalisedTitle(MessageText.getString("label.set.parent"));
+	
+						entry.prompt(new UIInputReceiverListener() {
+							@Override
+							public void UIInputReceiverClosed(UIInputReceiver entry) {
+								if (!entry.hasSubmittedInput()){
+	
+									return;
+								}
+	
+								String input = entry.getSubmittedInput().trim();
+	
+								if ( input.length() == 0 ){
+	
+									input = null;
+								}
+	
+								for ( Subscription sub: subs ){
+	
+									if ( sub.isSearchTemplate()){
+										continue;
+									}
+									sub.setParent( input );
+								}
+							}
+						});
+					}
+				});
+			}
+			
+			addExecOnNewResultSubMenu( menu_manager, menu_creator, all_subs );
+			
+			addDependsOnSubMenu( menu_manager, menu_creator, all_subs );
+			
+			menu_creator.createMenu( "s2").setStyle( MenuItem.STYLE_SEPARATOR );
+			
+				// refresh period
+	
+			MenuItem menuItem = menu_creator.createMenu(  "subs.prop.update_period" );
+		
+			menuItem.setText( menuItem.getText() + "..." );
+			
 			menuItem.addMultiListener(new SubsMenuItemListener() {
 				@Override
 				public void selected(final Subscription[] subs) {
 					UISWTInputReceiver entry = new SimpleTextEntryWindow();
-					if ( subs.length==1 ){
-						entry.setPreenteredText(subs[0].getParent(), false );
-					}
 					entry.maintainWhitespace(false);
-					entry.allowEmptyInput( true );
-					entry.setLocalisedTitle(MessageText.getString("label.set.parent"));
-
+					entry.allowEmptyInput( false );
+		
+					entry.setLocalisedTitle(MessageText.getString("subscriptions.enter.freq"));
+	
 					entry.prompt(new UIInputReceiverListener() {
 						@Override
 						public void UIInputReceiverClosed(UIInputReceiver entry) {
-							if (!entry.hasSubmittedInput()){
-
+							if (!entry.hasSubmittedInput()) {
 								return;
 							}
-
 							String input = entry.getSubmittedInput().trim();
+	
+							if ( input.length() > 0 ){
+	
+								try{
+									int num = Integer.parseInt( input );
+										
+									for ( Subscription sub: subs ){
+									
+										sub.getHistory().setCheckFrequencyMins( num);
 
-							if ( input.length() == 0 ){
-
-								input = null;
-							}
-
-							for ( Subscription sub: subs ){
-
-								sub.setParent( input );
+									}
+								}catch( Throwable e ){
+	
+									Debug.out( e );
+								}
 							}
 						}
 					});
 				}
 			});
+			
+			menu_creator.createMenu( "s3").setStyle( MenuItem.STYLE_SEPARATOR );
+			
 			return;
 		}
 
@@ -2161,7 +2308,7 @@ SubscriptionManagerUI
 
 				// sep
 
-			menu_creator.createMenu( "s1").setStyle( MenuItem.STYLE_SEPARATOR );
+			menu_creator.createMenu( "s4").setStyle( MenuItem.STYLE_SEPARATOR );
 
 				// category
 
@@ -2237,6 +2384,10 @@ SubscriptionManagerUI
 				}
 			});
 
+			addExecOnNewResultSubMenu( menu_manager, menu_creator, all_subs );
+
+			addDependsOnSubMenu( menu_manager, menu_creator, all_subs );
+			
 				// view options
 			
 			menuItem = menu_creator.createMenu( "menu.view.options");
@@ -2754,6 +2905,239 @@ SubscriptionManagerUI
 		});
 	}
 
+	private static void
+	addExecOnNewResultSubMenu(
+		MenuManager		menu_manager,
+		MenuCreator		menu_creator,
+		Subscription[]	menu_subs )	
+	{
+		if ( menu_subs.length != 1 ){
+			
+			return;
+		}
+		
+		Subscription subs = menu_subs[0];
+		
+		MenuItem menuItem = menu_creator.createMenu( "menu.exec.on.new.result");
+
+		menuItem.setStyle( MenuItem.STYLE_MENU );	
+		
+		menuItem.addFillListener(
+			new MenuItemFillListener()
+			{
+				@Override
+				public void
+				menuWillBeShown(
+					MenuItem 	menu,
+					Object 		data )
+				{
+					menu.removeAllChildItems();
+		
+					MenuItem mi = menu_manager.addMenuItem( menu, "label.script" );
+
+					String script = subs.getExecuteOnNewResult();
+
+					if ( script == null ){
+						
+						script = "";
+					}
+					
+					String f_script = script;
+					
+					if ( script.length() > 30 ){
+						script = script.substring( 0, 30);
+					}
+
+					String msg = MessageText.getString( "label.script" );
+
+					if ( script.length() > 0 ){
+
+						msg += ": " + script;
+					}
+
+					msg += "...";
+
+					mi.setText( msg );
+
+					mi.addListener((m,ev)->{
+						String msg2 = MessageText.getString( "UpdateScript.message" );
+		
+						SimpleTextEntryWindow entryWindow = new SimpleTextEntryWindow( "UpdateScript.title", "!" + msg2 + "!" );
+		
+						entryWindow.setPreenteredText( f_script, false );
+						
+						entryWindow.selectPreenteredText( true );
+		
+						entryWindow.prompt(new UIInputReceiverListener() {
+							@Override
+							public void UIInputReceiverClosed(UIInputReceiver entryWindow) {
+								if ( entryWindow.hasSubmittedInput()){
+		
+									String text = entryWindow.getSubmittedInput().trim();
+		
+									subs.setExecuteOnNewResult( text );
+								}
+							}
+						});
+					});
+				}});
+
+	}
+	
+	private static void
+	addDependsOnSubMenu(
+		MenuManager		menu_manager,
+		MenuCreator		menu_creator,
+		Subscription[]	menu_subs )	
+	{
+		MenuItem menuItem = menu_creator.createMenu( "menu.depends.on");
+
+		menuItem.setStyle( MenuItem.STYLE_MENU );
+
+		menuItem.addFillListener(
+			new MenuItemFillListener()
+			{
+				@Override
+				public void
+				menuWillBeShown(
+					MenuItem 	menu,
+					Object 		data )
+				{
+					menu.removeAllChildItems();
+
+					SubscriptionManager subs_man = SubscriptionManagerFactory.getSingleton();
+
+					Subscription[] all_subs = subs_man.getSubscriptions( true );
+
+					List<Subscription>	templates = new ArrayList<>();
+					
+					for ( Subscription sub: all_subs ){
+						
+						if ( sub.isSubscriptionTemplate()){
+							
+							templates.add( sub );
+						}
+					}
+					
+					if ( templates.isEmpty()){
+						
+						MenuItem mi = menu_manager.addMenuItem( menu, "menu.no.subs.templates" );
+
+						mi.setStyle( MenuItem.STYLE_RADIO );
+						
+						mi.setData( true );
+						
+						mi.setEnabled( false );
+						
+						mi = menu_manager.addMenuItem( menu, "sep" );
+
+						mi.setStyle( MenuItem.STYLE_SEPARATOR );
+						
+						mi = menu_manager.addMenuItem( 
+								menu, 
+								"!" + MessageText.getString( "Wizard.Subscription.template.title" ) + "...!" );
+
+						mi.addListener((m,ev)->{
+														
+							new SubscriptionWizard( SubscriptionWizard.MODE_CREATE_TEMPLATE );
+						});
+						
+					}else{
+						
+						Set<Subscription>	enabled = new HashSet<>();
+						
+						List<Subscription> menu_templates 	= new ArrayList<>();
+						List<Subscription> menu_search		= new ArrayList<>();
+						
+						for ( Subscription subs: menu_subs ){
+							
+							if ( subs.isSearchTemplate()){
+								
+								menu_search.add( subs );
+								
+								continue;
+								
+							}else if ( subs.isSubscriptionTemplate()){
+								
+								menu_templates.add( subs );
+							}								
+							
+							List<Subscription> depends_on = subs.getDependsOn();
+							
+							if ( depends_on.isEmpty()){
+								
+								enabled.clear();
+								
+								break;
+								
+							}else{
+								
+								if ( enabled.isEmpty()){
+									
+									enabled.addAll( depends_on );
+									
+								}else{
+									
+									enabled.retainAll( depends_on );
+									
+									if ( enabled.isEmpty()){
+										
+										break;
+									}
+								}
+							}
+						}
+						
+						if ( menu_search.size() == menu_subs.length){
+							
+							return;
+						}
+						
+						Collections.sort( templates,(t1,t2)->t1.getName().compareTo(t2.getName()));
+						
+						for ( Subscription sub: templates ){
+							
+							if ( menu_templates.contains( sub )){
+								
+								continue;
+							}
+							
+							MenuItem mi = menu_manager.addMenuItem( menu, "!" + sub.getName() + "!" );
+
+							mi.setStyle( MenuItem.STYLE_CHECK );
+							
+							boolean enable = enabled.contains( sub );
+							
+							mi.setData( enable );
+
+							mi.addMultiListener((m,target)->{							
+								for ( Subscription s: menu_subs ){
+									
+									if ( s.isSearchTemplate()){
+										
+										continue;
+									}
+									
+									List<Subscription> deps = s.getDependsOn();
+									
+									if ( enable ){
+										
+										deps.remove( sub );
+										
+									}else{
+										
+										deps.add( sub );
+									}
+									
+									s.setDependsOn( deps );
+								}
+							});
+						}
+					}
+				}
+			});
+	}
+	
 	private static void
 	addCategorySubMenu(
 		MenuManager				menu_manager,
@@ -3073,6 +3457,15 @@ SubscriptionManagerUI
 						try{
 							VuzeFile vf = subs.getVuzeFile();
 
+							List<Subscription> deps = SubscriptionUtils.getDependsOnClosure(subs);
+							
+							if ( !deps.isEmpty()){
+								
+								for ( Subscription dep: deps ){
+									
+									vf.addComponents( dep.getVuzeFile());
+								}
+							}
 							vf.write( new File( path ));
 
 						}catch( Throwable e ){
@@ -3314,6 +3707,8 @@ SubscriptionManagerUI
 				selected(subs.toArray( new Subscription[0]));
 			}else if ( target instanceof Subscription ){
 				selected((Subscription)target);
+			}else{
+				Debug.out( "target " + target + " not handled" );
 			}
 		}
 
