@@ -403,7 +403,7 @@ public class GeneralView
     availabilityPercent.setLayoutData(gridData);
     Messages.setLanguageText(availabilityPercent.getWidget(), "GeneralView.label.status.pieces_available.tooltip");
 
-    gTransfer = new Group(genComposite, SWT.SHADOW_OUT);
+    gTransfer = Utils.createSkinnedGroup(genComposite, SWT.SHADOW_OUT);
     Messages.setLanguageText(gTransfer, "GeneralView.section.transfer"); //$NON-NLS-1$
     gridData = new GridData(GridData.FILL_HORIZONTAL);
     gTransfer.setLayoutData(gridData);
@@ -499,7 +499,7 @@ public class GeneralView
 
     ////////////////////////
 
-    gInfo = new Group(genComposite, SWT.SHADOW_OUT);
+    gInfo = Utils.createSkinnedGroup(genComposite, SWT.SHADOW_OUT);
     Messages.setLanguageText(gInfo, "GeneralView.section.info");
     gridData = new GridData(GridData.FILL_BOTH);
     gInfo.setLayoutData(gridData);
@@ -564,7 +564,7 @@ public class GeneralView
     hash.setLayoutData(gridData);
     	// click on hash -> copy to clipboard
     hash.setCursor(display.getSystemCursor(SWT.CURSOR_HAND));
-    hash.setForeground(display.getSystemColor(SWT.COLOR_LINK_FOREGROUND));
+    Utils.setLinkForeground(hash.getControl());
     label.addMouseListener(new MouseAdapter() {
     	@Override
 	    public void mouseDoubleClick(MouseEvent arg0) {
@@ -707,7 +707,7 @@ public class GeneralView
     layout.marginHeight=layout.marginLeft=layout.marginRight=layout.marginWidth=0;
     cThumb.setLayout(layout);
 
-    Group gThumb = new Group( cThumb, SWT.NULL );
+    Group gThumb = Utils.createSkinnedGroup( cThumb, SWT.NULL );
     gridData = new GridData(GridData.FILL_HORIZONTAL);
     gThumb.setLayoutData(gridData);
     layout =  new GridLayout( 1, false );
@@ -843,7 +843,7 @@ public class GeneralView
     gridData = new GridData(GridData.VERTICAL_ALIGN_BEGINNING);
     label.setLayoutData(gridData);
     label.setCursor(display.getSystemCursor(SWT.CURSOR_HAND));
-    label.setForeground(display.getSystemColor(SWT.COLOR_LINK_FOREGROUND));
+    Utils.setLinkForeground(label);
     Messages.setLanguageText(label, "GeneralView.label.user_comment");
 
     try {
@@ -1538,7 +1538,14 @@ public class GeneralView
 
 	    if ( dm == null ){
 	    	
-	    	dm = manager.getDiskManagerPiecesSnapshot()[0].getManager();
+	    	DiskManagerPiece[] pieces = manager.getDiskManagerPiecesSnapshot();
+	    	
+	    	if ( pieces == null || pieces.length == 0 ){
+	    		
+	    		return;
+	    	}
+	    	
+	    	dm = pieces[0].getManager();
 	    }
 	    
 	    int	nbPieces = manager.getNbPieces();
