@@ -82,6 +82,13 @@ public class PiecesView
 		}
 	}
 	
+	@Override
+	protected 
+	String getTableID()
+	{
+		return(TableManager.TABLE_TORRENT_PIECES );
+	}
+	
 	@Override
 	public TableViewSWT<PEPiece> 
 	initYourTableView() 
