@@ -44,6 +44,7 @@ import com.biglybt.ui.swt.Messages;
 import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.config.*;
 import com.biglybt.ui.swt.imageloader.ImageLoader;
+import com.biglybt.ui.swt.mainwindow.ClipboardCopy;
 import com.biglybt.ui.swt.mainwindow.Colors;
 import com.biglybt.ui.swt.pif.UISWTView;
 import com.biglybt.ui.swt.pif.UISWTViewEvent;
@@ -98,6 +99,8 @@ public class TagSettingsView
 		public BooleanSwtParameter boost;
 
 		public IntSwtParameter maxActiveDownloads;
+		public IntSwtParameter maxActiveSeeders;
+		public BooleanSwtParameter activeLimitsStrict;
 
 		public BooleanSwtParameter firstPrioritySeeding;
 
@@ -137,10 +140,12 @@ public class TagSettingsView
 
 
 		
-		public Text		 	constraints;
-		public Label		constraintError;
+		public Text		 				constraints;
+		public Label					constraintError;
 		public BooleanSwtParameter 		constraintEnabled;
 		public StringListSwtParameter 	constraintMode;
+		public IntSwtParameter			constraintWeight;
+		public IntSwtParameter 			constraintTagSortAuto;
 
 		public IntSwtParameter tfl_max_taggables;
 
@@ -614,7 +619,7 @@ public class TagSettingsView
 
 			if (tagsAreTagFeatureRateLimit) {
 				
-				Group gTransfer = new Group(cMainComposite, SWT.NONE);
+				Group gTransfer = Utils.createSkinnedGroup(cMainComposite, SWT.NONE);
 				gTransfer.setText( MessageText.getString("label.transfer.settings"));
 				final int gTransferCols = 8;
 				gridLayout = new GridLayout(gTransferCols, false);
@@ -1059,7 +1064,7 @@ public class TagSettingsView
 				}
 				
 				if (supportsMaxCDS){
-					params.maxActiveDownloads = new IntSwtParameter(gTransfer,
+					params.maxActiveSeeders = new IntSwtParameter(gTransfer,
 							"tag.maxActiveSeeds", "ConfigView.label.maxseeding", null, 0, Integer.MAX_VALUE,
 							new IntSwtParameter.ValueProcessor() {
 								@Override
@@ -1091,6 +1096,43 @@ public class TagSettingsView
 					cols_used += 2;
 				}
 				
+				if (supportsMaxDLS||supportsMaxCDS){
+					params.activeLimitsStrict = new BooleanSwtParameter(gTransfer,
+							"tag.activelimitsstrict", "label.strict.limits", null,
+							new BooleanSwtParameter.ValueProcessor() {
+								@Override
+								public Boolean getValue(BooleanSwtParameter p) {
+									int value = -1;
+									for (TagFeatureRateLimit rl : rls) {
+										value = updateIntBoolean(rl.getStrictActivityLimits(),
+												value);
+									}
+									return value == 2 ? null : value == 1;
+								}
+
+								@Override
+								public boolean setValue(BooleanSwtParameter p, Boolean value) {
+									boolean changed = rls.length == 0;
+									for (TagFeatureRateLimit rl : rls) {
+										if (rl.getStrictActivityLimits() != value) {
+											rl.setStrictActivityLimits(value);
+											changed = true;
+										}
+									}
+									return changed;
+								}
+							});
+					cols_used += 2;
+				}
+				
+				if ( cols_used > 0 && cols_used < gTransferCols){			
+					Label lab = new Label( gTransfer, SWT.NULL );
+					gd = new GridData();
+					gd.horizontalSpan = gTransferCols - cols_used;
+					lab.setLayoutData(gd);		
+					cols_used = 0;
+				}
+				
 				if (supportsFPSeeding) {
 					params.firstPrioritySeeding = new BooleanSwtParameter(gTransfer,
 							"tag.firstPrioritySeeding", "label.first.priority.seeding", null,
@@ -1139,7 +1181,7 @@ public class TagSettingsView
 						fl.supportsTagMoveOnRemove() ||
 						fl.supportsTagMoveOnAssign()) {
 
-					Group gFiles = new Group(cMainComposite, SWT.NONE);
+					Group gFiles = Utils.createSkinnedGroup(cMainComposite, SWT.NONE);
 					gFiles.setText(MessageText.getString( "label.file.settings"));
 					// label, button, value, cb*2, cb*2 = 8
 					gridLayout = new GridLayout(8, false);
@@ -1550,8 +1592,11 @@ public class TagSettingsView
 
 				final TagProperty propConstraint = tfp.getProperty(
 						TagFeatureProperties.PR_CONSTRAINT);
+				
+				TagDownload tag_dl = tags[0] instanceof TagDownload?(TagDownload)tags[0]:null;
+
 				if (propConstraint != null) {
-					Group gConstraint = new Group(cMainComposite, SWT.NONE);
+					Group gConstraint = Utils.createSkinnedGroup(cMainComposite, SWT.NONE);
 					Messages.setLanguageText(gConstraint, "tag.property.constraint");
 					gridLayout = new GridLayout();
 					gConstraint.setLayout(gridLayout);
@@ -1606,14 +1651,16 @@ public class TagSettingsView
 					
 					params.constraintError = new Label(gConstraint, SWT.NULL );
 					params.constraintError.setLayoutData( new GridData( GridData.FILL_HORIZONTAL ));
-					params.constraintError.setForeground( Colors.colorError);
+					
+					Utils.setSkinnedForeground( params.constraintError, Colors.colorError, true );
 
 					Composite cConstraintOptions = new Composite(gConstraint, SWT.NULL);
-					RowLayout layout = new RowLayout(SWT.HORIZONTAL);
-					layout.spacing = 5;
-					layout.center = true;
-					cConstraintOptions.setLayout(layout);
-
+					cConstraintOptions.setLayoutData(new GridData( GridData.FILL_HORIZONTAL));
+					gridLayout = new GridLayout(11,false);
+					gridLayout.marginLeft = gridLayout.marginRight = gridLayout.marginWidth = 0;
+					gridLayout.marginTop = gridLayout.marginBottom = gridLayout.marginHeight = 0;
+					cConstraintOptions.setLayout(gridLayout);
+					
 					btnSaveConstraint = new Button(cConstraintOptions, SWT.PUSH);
 					btnSaveConstraint.setEnabled(false);
 					btnSaveConstraint.addListener(SWT.Selection, new Listener() {
@@ -1724,6 +1771,23 @@ public class TagSettingsView
 								}
 							});
 
+					params.constraintWeight = new IntSwtParameter(cConstraintOptions,
+							"tag_constraint_weight", "tag.constraints.weight", null,
+							Integer.MIN_VALUE, Integer.MAX_VALUE, new IntSwtParameter.ValueProcessor() {
+								@Override
+								public Integer getValue(IntSwtParameter p) {
+									return(((TagDownload)tags[0]).getWeight());
+								}
+
+								@Override
+								public boolean setValue(IntSwtParameter p, Integer value) {
+									((TagDownload)tags[0]).setWeight( value );
+									return true;
+								}
+							} );
+					
+					params.constraintWeight.setEnabled( tag_dl != null );
+					
 					Link lblAboutConstraint = new Link(cConstraintOptions, SWT.WRAP);
 					lblAboutConstraint.setText(
 							MessageText.getString("tag.constraints.info"));
@@ -1737,6 +1801,47 @@ public class TagSettingsView
 						}
 					});
 
+					ClipboardCopy.addCopyToClipMenu(lblAboutConstraint);
+					
+					Composite cApplySort = new Composite(gConstraint, SWT.NULL);
+					cApplySort.setLayoutData(new GridData( GridData.FILL_HORIZONTAL));
+					
+					gridLayout = new GridLayout(10,false);
+					gridLayout.marginLeft = gridLayout.marginRight = gridLayout.marginWidth = 0;
+					gridLayout.marginTop = gridLayout.marginBottom = gridLayout.marginHeight = 0;
+					cApplySort.setLayout( gridLayout );
+										
+					Label lApplySort = new Label( cApplySort, SWT.NULL );
+					
+					lApplySort.setText(	MessageText.getString( "tag.constraints.sort.apply.manual" ));
+					
+					Button btnApply = new Button(cApplySort, SWT.PUSH);
+		
+					btnApply.addListener(SWT.Selection, new Listener() {
+						@Override
+						public void handleEvent(Event event) {
+							tag_dl.applySort();
+						}
+					});
+					Messages.setLanguageText(btnApply, "Button.apply");
+					btnApply.setEnabled( tag_dl != null );
+					
+					params.constraintTagSortAuto = new IntSwtParameter(cApplySort,
+							"tag_constraint_tag_sort_auto", "tag.constraints.sort.apply.auto", null,
+							0, Integer.MAX_VALUE, new IntSwtParameter.ValueProcessor() {
+								@Override
+								public Integer getValue(IntSwtParameter p) {
+									return(((TagDownload)tags[0]).getAutoApplySortInterval());
+								}
+
+								@Override
+								public boolean setValue(IntSwtParameter p, Integer value) {
+									((TagDownload)tags[0]).setAutoApplySortInterval( value );
+									return true;
+								}
+							} );
+					
+					params.constraintTagSortAuto.setEnabled( tag_dl != null );
 				}
 			}
 
@@ -1749,7 +1854,7 @@ public class TagSettingsView
 
 					/////////////////////////////// limits
 
-					Group gLimits = new Group(cMainComposite, SWT.NONE);
+					Group gLimits = Utils.createSkinnedGroup(cMainComposite, SWT.NONE);
 					gLimits.setText(MessageText.getString("label.limit.settings"));
 					gridLayout = new GridLayout(6, false);
 					gLimits.setLayout(gridLayout);
@@ -1845,7 +1950,7 @@ public class TagSettingsView
 
 					// notifications
 
-				Group gNotifications = new Group(cMainComposite, SWT.NONE);
+				Group gNotifications = Utils.createSkinnedGroup(cMainComposite, SWT.NONE);
 				gNotifications.setText(MessageText.getString("v3.MainWindow.tab.events"));
 				gridLayout = new GridLayout(6, false);
 				gNotifications.setLayout(gridLayout);
