@@ -200,6 +200,8 @@ public class PieceMapView
 			oldBlockInfo = null;
 		}
 
+		topLabelRHS = "";
+		
 		synchronized( this ){
 			if (dlm != null) {
 				dlm.removePieceListener(this);
@@ -223,6 +225,8 @@ public class PieceMapView
 		if ( dlm != null ){
 			fillPieceInfoSection();
 		}
+		
+		Utils.execSWTThread(()->updateTopLabel());
 	}
 
 	private static String getFullTitle() {
@@ -293,7 +297,9 @@ public class PieceMapView
 		imageLabel.setLayoutData(gridData);
 
 		topLabel = new BufferedLabel(pieceInfoComposite, SWT.DOUBLE_BUFFERED);
-		topLabel.getControl().setBackground(Colors.white);
+		if ( !Utils.isDarkAppearanceNative()){
+			topLabel.getControl().setBackground(Colors.white);
+		}
 		gridData = new GridData(SWT.FILL, SWT.DEFAULT, true, false);
 		topLabel.setLayoutData(gridData);
 
@@ -760,6 +766,10 @@ public class PieceMapView
 	private void
 	updateTopLabel()
 	{
+		if ( topLabel == null || topLabel.isDisposed()){
+			return;
+		}
+		
 		String text = topLabelLHS;
 		
 		if (selectedPieceExplicit != null) {
