@@ -45,9 +45,10 @@ import com.biglybt.ui.mdi.MultipleDocumentInterface;
 import com.biglybt.ui.swt.FixedHTMLTransfer;
 import com.biglybt.ui.swt.FixedURLTransfer;
 import com.biglybt.ui.swt.MenuBuildUtils;
-import com.biglybt.ui.swt.UIFunctionsManagerSWT;
 import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.debug.ObfuscateImage;
+import com.biglybt.ui.swt.mainwindow.Colors;
+import com.biglybt.ui.swt.mainwindow.SWTThread;
 import com.biglybt.ui.swt.mainwindow.TorrentOpener;
 import com.biglybt.ui.swt.mdi.*;
 import com.biglybt.ui.swt.pif.UISWTInstance;
@@ -55,6 +56,7 @@ import com.biglybt.ui.swt.pif.UISWTViewEvent;
 import com.biglybt.ui.swt.pif.UISWTViewEventListener;
 import com.biglybt.ui.swt.pifimpl.UISWTInstanceImpl.SWTViewListener;
 import com.biglybt.ui.swt.pifimpl.*;
+import com.biglybt.ui.swt.shells.PopOutManager;
 import com.biglybt.ui.swt.shells.main.MainMDISetup;
 import com.biglybt.ui.swt.skin.*;
 import com.biglybt.ui.swt.uiupdater.UIUpdaterSWT;
@@ -63,11 +65,9 @@ import com.biglybt.ui.swt.views.IViewAlwaysInitialize;
 import com.biglybt.ui.swt.views.QuickLinksView;
 import com.biglybt.ui.swt.views.ViewManagerSWT;
 import com.biglybt.ui.swt.views.configsections.ConfigSectionInterfaceDisplaySWT;
-import com.biglybt.ui.swt.views.skin.SkinnedDialog;
 import com.biglybt.util.JSONUtils;
 import com.biglybt.pif.PluginInterface;
 import com.biglybt.pif.PluginManager;
-import com.biglybt.pif.download.Download;
 import com.biglybt.pif.ui.UIInstance;
 import com.biglybt.pif.ui.UIManager;
 import com.biglybt.pif.ui.menus.MenuItem;
@@ -289,6 +289,42 @@ public class SideBar
 			menuItem.addListener((menu, target) -> closeEntry(getCurrentEntry(), true ));
 		}
 		
+		{
+			MenuItem menuItem = menuManager.addMenuItem("sidebar._end_", "menu.show.at.start");
+			menuItem.setDisposeWithUIDetach(UIInstance.UIT_SWT);
+			menuItem.setStyle( MenuItem.STYLE_CHECK );	
+			menuItem.setData( false );
+			menuItem.addFillListener(
+				new MenuItemFillListener() {
+	
+					@Override
+					public void menuWillBeShown(MenuItem menu, Object data) {
+						SideBarEntrySWT sbe = getCurrentEntry();
+	
+						if ( sbe != null ){
+							String id = sbe.getId();
+							
+							String sas = COConfigurationManager.getStringParameter( "Show Side Entry At Start", "" );
+							
+							menu.setData( sas.equals( id ));
+							
+						}else{
+							
+							menu.setVisible( false );
+						}
+					}
+				});
+	
+			menuItem.addListener((menu, target) -> {
+				SideBarEntrySWT sbe = getCurrentEntry();
+				
+				if ( sbe != null ){
+					
+					COConfigurationManager.setParameter( "Show Side Entry At Start", menu.isSelected()?sbe.getId():"");
+				}
+			});
+		}
+		
 		{
 			MenuItem menuParentItem = menuManager.addMenuItem("sidebar._end_", "menu.add.to");
 			menuParentItem.setDisposeWithUIDetach(UIInstance.UIT_SWT);
@@ -340,6 +376,20 @@ public class SideBar
 				}
 			});
 			
+			MenuItem menuItemTopbar = menuManager.addMenuItem( menuParentItem, "label.topbar");
+
+			menuItemTopbar.addListener(new MenuItemListener() {
+				@Override
+				public void selected(MenuItem menu, Object target) {
+					SideBarEntrySWT sbe = getCurrentEntry();
+	
+					if ( sbe != null ){
+						
+						MainMDISetup.getSb_dashboard().addItemToTopbar( sbe );
+					}
+				}
+			});
+			
 			MenuItem menuItemSidebar = menuManager.addMenuItem( menuParentItem, "label.sidebar");
 
 			menuItemSidebar.addListener(new MenuItemListener() {
@@ -410,7 +460,7 @@ public class SideBar
 	
 					if ( sbe != null ){
 
-						popoutEntry( sbe, menu==menuItemOnTop );
+						popoutEntry( sbe, menu==menuItemOnTop?PopOutManager.OPT_MAP_ON_TOP:PopOutManager.OPT_MAP_NONE );
 					}
 				}
 			};
@@ -420,6 +470,13 @@ public class SideBar
 		}
 	}
 
+	@Override
+	protected String
+	getShowIDAtStartup()
+	{
+		return(COConfigurationManager.getStringParameter( "Show Side Entry At Start", "" ));
+	}
+	
 	public boolean
 	canPopoutEntry(
 		MdiEntry	entry )
@@ -431,49 +488,10 @@ public class SideBar
 	
 	public boolean
 	popoutEntry(
-		MdiEntry	entry,
-		boolean		onTop )
+		MdiEntry			entry,
+		Map<String,Object>	options )
 	{
-		SideBarEntrySWT sbe = (SideBarEntrySWT)entry;
-		
-		SkinnedDialog skinnedDialog =
-				new SkinnedDialog(
-						"skin3_dlg_sidebar_popout",
-						"shell",
-						onTop?UIFunctionsManagerSWT.getUIFunctionsSWT().getMainShell():null,
-						SWT.RESIZE | SWT.MAX | SWT.DIALOG_TRIM);
-	
-		SWTSkin skin = skinnedDialog.getSkin();
-	
-		SWTSkinObjectContainer cont = sbe.buildStandAlone((SWTSkinObjectContainer)skin.getSkinObject( "content-area" ));
-	
-		if ( cont != null ){
-	
-			skinnedDialog.setTitle( sbe.getTitle());
-	
-			String metrics_id;
-			
-				// hack - we don't want to remember shell metrics on a per-download basis
-			
-			if ( sbe.getDatasource() instanceof Download ){
-				
-				metrics_id = MultipleDocumentInterface.SIDEBAR_SECTION_TORRENT_DETAILS;
-				
-			}else{
-				
-				metrics_id = sbe.getId();
-			}
-			
-			skinnedDialog.open( "mdi.popout:" + metrics_id, true );
-	
-			return( true );
-			
-		}else{
-	
-			skinnedDialog.close();
-			
-			return( false );
-		}
+		return( PopOutManager.popOut((SideBarEntrySWT)entry, options ));
 	}
 
 	/**
@@ -633,6 +651,26 @@ public class SideBar
 		return super.skinObjectDestroyed(skinObject, params);
 	}
 
+	protected void
+	setBackground(
+		SWTSkinProperties	sp )
+	{
+		if ( Utils.isDarkAppearanceNativeWindows()){
+			
+			bg = Colors.getWindowsDarkSystemColor( tree.getDisplay(), SWT.COLOR_WIDGET_BACKGROUND ); 
+			
+		}else{
+		
+			bg = sp.getColor("color.sidebar.bg");
+		}
+	}
+	
+	protected Color
+	getBackground()
+	{
+		return( bg );
+	}
+	
 	private void createSideBar() {
 		
 		SWTSkinObject soSideBarList = skin.getSkinObject("sidebar-list");
@@ -666,7 +704,8 @@ public class SideBar
 		tree.setLayoutData(Utils.getFilledFormData());
 
 		SWTSkinProperties skinProperties = skin.getSkinProperties();
-		bg = skinProperties.getColor("color.sidebar.bg");
+		
+		setBackground( skinProperties );
 		fg = skinProperties.getColor("color.sidebar.fg");
 
 		configBGColorListener = new ParameterListener() {
@@ -1077,7 +1116,7 @@ public class SideBar
 										
 										if ( canPopoutEntry(entry)){
 										
-											done = popoutEntry( entry, true );
+											done = popoutEntry( entry, PopOutManager.OPT_MAP_ON_TOP );
 										}
 									}
 								}
@@ -1443,6 +1482,10 @@ public class SideBar
 				});
 			}
 		}
+		
+		Utils.addTerminateListener(()->{
+			saveCloseables();
+		});
 	}
 
 	private void createSideBarPluginViews() {
@@ -1704,7 +1747,7 @@ public class SideBar
 
 		skinProperties.clearCache();
 
-		bg = skinProperties.getColor("color.sidebar.bg");
+		setBackground( skinProperties );
 
 		tree.setBackground(bg);
 
