@@ -997,6 +997,10 @@ public abstract class TableViewSWT_Common
 								}
 							}
 							
+							@Override
+							public void buildStarts(Menu menu){
+							}
+							
 							@Override
 							public void buildComplete(Menu menu){
 							}
@@ -1085,9 +1089,7 @@ public abstract class TableViewSWT_Common
 			// Add Plugin Context menus..
 			TableContextMenuItem[] items = column.getContextMenuItems(TableColumnCore.MENU_STYLE_HEADER);
 			if (items.length > 0) {
-				if (menu.getItemCount() > 0) {
-					new MenuItem(menu, SWT.SEPARATOR);
-				}
+				MenuBuildUtils.addSeparator( menu );
 
 				MenuBuildUtils.addPluginMenuItems(items, menu, true, true,
 					new MenuBuildUtils.MenuItemPluginMenuControllerImpl(
@@ -1095,9 +1097,7 @@ public abstract class TableViewSWT_Common
 
 			}
 
-			if (menu.getItemCount() > 0) {
-				new MenuItem(menu, SWT.SEPARATOR);
-			}
+			MenuBuildUtils.addSeparator( menu );
 
 			TableColumnCore[] sortColumns = tv.getSortColumns();
 			boolean columnIsSort = false;
@@ -1112,9 +1112,7 @@ public abstract class TableViewSWT_Common
 				Messages.setLanguageText(menuSortByColumn, "TableColumn.sort.reverse");
 				menuSortByColumn.addListener(SWT.Selection, e -> {
 					TableColumnCore tcc = (TableColumnCore) menu.getData("column");
-
-					tcc.setSortAscending(!tcc.isSortAscending());
-					tv.setSortColumns(tv.getSortColumns(), false);
+					tv.addSortColumn( tcc ); // this flips sort if already added and does history...
 				});
 				if (sortColumns.length > 1) {
 					MenuItem menuRemoveSort = new MenuItem(menu, SWT.PUSH);
