@@ -49,6 +49,8 @@ public class TableRowPainted
 {
 	private static final boolean DEBUG_SUBS = false;
 
+	private final boolean isFake;
+	
 	private Point drawOffset = new Point(0, 0);
 
 	private int numSubItems;
@@ -84,6 +86,9 @@ public class TableRowPainted
 		// calls the TableView and causes locks.  So, use the TableView's sync!
 
 		super(tv.getSyncObject(), parentRow, tv, dataSource);
+		
+		isFake = false;
+		
 		subRows_sync = tv.getSyncObject();
 
 		TableColumnCore[] sortColumns = tv.getSortColumns();
@@ -119,6 +124,45 @@ public class TableRowPainted
 		tv.rowCreated();
 	}
 
+		/**
+		 * FAKE row constructor
+		 * 
+		 * @param parentRow
+		 * @param tv
+		 * @param dataSource
+		 */
+	
+	public 
+	TableRowPainted(
+		TableRowCore 		parentRow, 
+		TableViewPainted 	tv,
+		Object 				dataSource )
+	{
+		super(tv.getSyncObject(), parentRow, tv, dataSource);
+		
+		isFake = true;
+				
+		subRows_sync = tv.getSyncObject();
+
+		isHidden = false;
+				
+		if ( dataSource instanceof TableRowSWTChildController ){
+			
+			TableRowSWTChildController c = (TableRowSWTChildController)dataSource;
+			
+			setExpanded( c.isExpanded(), false );
+			
+			Object[] kids = c.getChildDataSources();
+			
+			if ( kids != null && kids.length > 0 ){
+				
+				setSubItems( kids, false );
+			}
+		}
+		
+		initializing = false;
+	}
+	
 	public boolean
 	refilter()
 	{		
@@ -191,6 +235,18 @@ public class TableRowPainted
 		return( isHidden );
 	}
 	
+	@Override
+	public void invalidate(boolean mustRefersh) {
+		super.invalidate(mustRefersh);
+		synchronized (lock) {
+			if (sortCells != null) {
+				for (TableCellSWTBase sortCell : sortCells) {
+					sortCell.invalidate(mustRefersh);
+				}
+			}
+		}
+	}
+	
 	private void buildCells() {
 		//debug("buildCells " + Debug.getCompressedStackTrace());
 		TableColumnCore[] visibleColumns = getView().getVisibleColumns();
@@ -402,10 +458,12 @@ public class TableRowPainted
 							gc.setBackground(bg);
 							gc.fillRectangle(r);
 							if (isSelected) {
-  							gc.setAlpha(80);
-  							gc.setForeground(altColor);
-  							gc.fillGradientRectangle(r.x, r.y, r.width, r.height, true);
-  							gc.setForeground(fg);
+								if ( Utils.gradientFillSelection()){
+									gc.setAlpha(80);
+									gc.setForeground(altColor);
+									gc.fillGradientRectangle(r.x, r.y, r.width, r.height, true);
+									gc.setForeground(fg);
+								}
 							}
 						}
 						gc.setAlpha(rowAlpha);
@@ -463,10 +521,12 @@ public class TableRowPainted
   				} else {
   					gc.fillRectangle(r);
   					if (isSelected) {
-  						gc.setAlpha(80);
-  						gc.setForeground(altColor);
-  						gc.fillGradientRectangle(r.x, r.y, r.width, r.height, true);
-  						gc.setForeground(fg);
+  						if ( Utils.gradientFillSelection()){
+	  						gc.setAlpha(80);
+	  						gc.setForeground(altColor);
+	  						gc.fillGradientRectangle(r.x, r.y, r.width, r.height, true);
+	  						gc.setForeground(fg);
+  						}
   					}
   				}
   				gc.setAlpha(rowAlpha);
@@ -568,7 +628,20 @@ public class TableRowPainted
 		}
 
 		boolean gcChanged = false;
+		Rectangle oldClipping = null;
+		
 		try {
+			if ( Constants.IS_CVS_VERSION ){
+				// The cell bounds unfortunately includes the pixel on the right that is used to draw the column separators.
+				// It is a big job to amend things so that the width from cell.getBounds() returns an area excluding this so 
+				// at least clip things so that cells that try and use this "extra" pixel will see the problem...
+				
+				oldClipping = gc.getClipping();
+				int marginWidth		= cell.getMarginWidth();	// meh, some cells draw over their specified margin area (e.g. old progress-eta)
+				int marginHeight	= cell.getMarginHeight();
+				Utils.setClipping(gc, new Rectangle( cellBounds.x-marginWidth, cellBounds.y-marginHeight, cellBounds.width+marginWidth*2-1, cellBounds.height+marginHeight*2 ));
+			}
+			
 			if ( inPaintItem ){
 				Debug.out( "hmm");
 				return( false );
@@ -799,6 +872,9 @@ public class TableRowPainted
 		} catch (Exception e) {
 			Debug.out(cell.getTableID() + ":" + cell.getTableColumn().getName(), e );
 		}finally{
+			if ( Constants.IS_CVS_VERSION ){
+				Utils.setClipping(gc, oldClipping);
+			}
 			inPaintItem = false;
 		}
 
@@ -871,6 +947,9 @@ public class TableRowPainted
 		if (isRowDisposed()) {
 			return;
 		}
+		if ( isFake ){
+			return;
+		}
 		getViewPainted().redrawRow(this, immediateRedraw);
 
 		if (!doChildren) {
@@ -937,7 +1016,9 @@ public class TableRowPainted
 	 * @see com.biglybt.ui.swt.views.table.impl.TableRowSWTBase#heightChanged(int, int)
 	 */
 	public void heightChanged(int oldHeight, int newHeight) {
-		getViewPainted().rowHeightChanged(this, oldHeight, newHeight);
+		if ( !isFake ){
+			getViewPainted().rowHeightChanged(this, oldHeight, newHeight);
+		}
 		TableRowCore row = getParentRowCore();
 		if (row instanceof TableRowPainted) {
 			((TableRowPainted) row).subRowHeightChanged( oldHeight, newHeight);
@@ -1068,15 +1149,18 @@ public class TableRowPainted
 				((TableRowPainted) row).subRowHeightChanged( oldHeight, newHeight);
 			}
 			
-			TableViewPainted tvp = getViewPainted();
-
-			if ( triggerHeightListener ){
-					
-				tvp.rowHeightChanged(this, oldHeight, newHeight );
+			if ( !isFake ){
+				
+				TableViewPainted tvp = getViewPainted();
+	
+				if ( triggerHeightListener ){
+						
+					tvp.rowHeightChanged(this, oldHeight, newHeight );
+				}
+				
+				tvp.triggerListenerRowAdded(newSubRows);
 			}
 			
-			tvp.triggerListenerRowAdded(newSubRows);
-
 			subRows = newSubRows;
 		}
 	}
@@ -1222,15 +1306,16 @@ public class TableRowPainted
 					((TableRowPainted) row).subRowHeightChanged( oldHeight, newHeight);
 				}
 				
-				if ( triggerHeightChange ){
+				if ( !isFake ){
+					if ( triggerHeightChange ){
+						
+						getViewPainted().rowHeightChanged(this, oldHeight, newHeight);
+					}
 					
-					getViewPainted().rowHeightChanged(this, oldHeight, newHeight);
+					if (newSubRows != null) {
+						getViewPainted().triggerListenerRowAdded(newSubRows);
+					}
 				}
-				
-				if (newSubRows != null) {
-					getViewPainted().triggerListenerRowAdded(newSubRows);
-				}
-
 			}
 			
 			Object ds = getDataSource( true );
@@ -1240,17 +1325,20 @@ public class TableRowPainted
 				((TableRowSWTChildController)ds).setExpanded( b );
 			}
 			
-			TableViewPainted tvp = getViewPainted();
-
-			if ( triggerHeightChange ){
-			
-				tvp.tableMutated();
-			}
-			
-			if (isVisible()) {
-
-				tvp.visibleRowsChanged();
-				tvp.redrawTable();
+			if ( !isFake ){
+				
+				TableViewPainted tvp = getViewPainted();
+	
+				if ( triggerHeightChange ){
+				
+					tvp.tableMutated();
+				}
+				
+				if (isVisible()) {
+	
+					tvp.visibleRowsChanged();
+					tvp.redrawTable();
+				}
 			}
 		}
 	}
@@ -1495,6 +1583,14 @@ public class TableRowPainted
 		}
 	}
 
+	@Override
+	public TableCell 
+	getTableCell(
+		TableColumn column)
+	{
+		return( getTableCell( column.getName()));
+	}
+	
 	@Override
 	public TableCellSWT getTableCellSWT(String name) {
 		TableCellCore cell = getTableCellCore(name);
