@@ -68,10 +68,14 @@ public class SizeBytesItem
     	
     	text = "";
     	
+    	cell.setNumeric( Double.NaN );
+    	
     }else{
     	
     	text = NumberFormat.getNumberInstance().format( value );
     	
+    	cell.setNumeric( value );
+    	
     	if ( internal ){
     		
     		//text = "(" + text + ")";
